;//////////////////////////////////////////////////////////////////////////////
;//
;//  Copyright (C) Microsoft Corporation.  All Rights Reserved.
;//
;//  File:       d3dx9anim.inc
;//  Content:    D3DX mesh types and functions
;//
;//  Translated to .ASM by: Siekmanski
;//
;//////////////////////////////////////////////////////////////////////////////

ifndef __D3DX9_ANIM__
__D3DX9_ANIM__ equ 1

;// {A632D591-B584-4d03-BCCD-CBB5331F21AA}
IID_ID3DXAnimationSet	TEXTEQU <{0a632d591h,0b584h,04d03h,{0bch,0cdh,0cbh,0b5h,033h,01fh,021h,0aah}}>
;// {73B6DDE3-7E45-4cc8-834F-B7DCBC04D10A}
IID_ID3DXKeyframedAnimationSet	TEXTEQU <{073b6dde3h,07e45h,04cc8h,{083h,04fh,0b7h,0dch,0bch,004h,0d1h,00ah}}>
;// {7B7228FD-EA36-4c06-9DA6-E053D688E164}
IID_ID3DXCompressedAnimationSet	TEXTEQU <{07b7228fdh,0ea36h,04c06h,{09dh,0a6h,0e0h,053h,0d6h,088h,0e1h,064h}}>
;// {39F628C0-CD5B-41d6-8E9C-3BBBB66FDA57}
IID_ID3DXAnimationController	TEXTEQU <{039f628c0h,0cd5bh,041d6h,{08eh,09ch,03bh,0bbh,0b6h,06fh,0dah,057h}}>

;//----------------------------------------------------------------------------
;// D3DXMESHDATATYPE:
;// -----------------
;// This enum defines the type of mesh data present in a MeshData structure.
;//----------------------------------------------------------------------------

D3DXMESHTYPE_MESH		equ 001h ;// Normal ID3DXMesh data
D3DXMESHTYPE_PMESH		equ 002h ;// Progressive Mesh - ID3DXPMesh
D3DXMESHTYPE_PATCHMESH		equ 003h ;// Patch Mesh - ID3DXPatchMesh
D3DXMESHTYPE_FORCE_DWORD	equ 7fffffffh

D3DXMESHDATATYPE		typedef DWORD

;//----------------------------------------------------------------------------
;// D3DXMESHDATA:
;// -------------
;// This struct encapsulates a the mesh data that can be present in a mesh 
;// container.  The supported mesh types are pMesh, pPMesh, pPatchMesh.
;// The valid way to access this is determined by the Type enum.
;//----------------------------------------------------------------------------

_D3DXMESHDATA struct
	dx_Type		D3DXMESHDATATYPE ?
	;// current mesh data interface
	union
		pMesh		LPD3DXMESH ?
		pPMesh		LPD3DXPMESH ?
		pPatchMesh	LPD3DXPATCHMESH ?
	ends
_D3DXMESHDATA ends

D3DXMESHDATA			typedef _D3DXMESHDATA
LPD3DXMESHDATA			typedef PTR _D3DXMESHDATA

;//----------------------------------------------------------------------------
;// D3DXMESHCONTAINER:
;// ------------------
;// This struct encapsulates a mesh object in a transformation frame
;// hierarchy. The app can derive from this structure to add other app specific
;// data to this.
;//----------------------------------------------------------------------------

LPD3DXMESHCONTAINER		typedef PTR _D3DXMESHCONTAINER 

_D3DXMESHCONTAINER struct
	Name			DWORD ?
	MeshData		D3DXMESHDATA <?>
	pMaterials		LPD3DXMATERIAL ?    
	pEffects		LPD3DXEFFECTINSTANCE ?
	NumMaterials		DWORD ?
	pAdjacency		DWORD ?
	pSkinInfo		LPD3DXSKININFO ?
	pNextMeshContainer	LPD3DXMESHCONTAINER ? ; ptr to the next meshcontainer.
_D3DXMESHCONTAINER ends

D3DXMESHCONTAINER		typedef _D3DXMESHCONTAINER 

;//----------------------------------------------------------------------------
;// D3DXFRAME:
;// ----------
;// This struct is the encapsulates a transform frame in a transformation frame
;// hierarchy. The app can derive from this structure to add other app specific
;// data to this
;//----------------------------------------------------------------------------

LPD3DXFRAME			typedef PTR _D3DXFRAME

_D3DXFRAME struct
	Name			DWORD ?
	TransformationMatrix	D3DXMATRIX <?>
	pMeshContainer		LPD3DXMESHCONTAINER ?
	pFrameSibling		LPD3DXFRAME ?
	pFrameFirstChild	LPD3DXFRAME ?
_D3DXFRAME ends

D3DXFRAME			typedef _D3DXFRAME

;//----------------------------------------------------------------------------
;// ID3DXAllocateHierarchy:
;// -----------------------
;// This interface is implemented by the application to allocate/free frame and
;// mesh container objects. Methods on this are called during loading and
;// destroying frame hierarchies
;//----------------------------------------------------------------------------

_vtID3DXAllocateHierarchy MACRO CastName:REQ
	;// ID3DXAllocateHierarchy

	;//------------------------------------------------------------------------
	;// CreateFrame:
	;// ------------
	;// Requests allocation of a frame object.
	;//
	;// Parameters:
	;//  Name
	;//		Name of the frame to be created
	;//	ppNewFrame
	;//		Returns the created frame object
	;//
	;//------------------------------------------------------------------------

	&CastName&_CreateFrame			comethod3 ?

	;//------------------------------------------------------------------------
	;// CreateMeshContainer:
	;// --------------------
	;// Requests allocation of a mesh container object.
	;//
	;// Parameters:
	;//  Name
	;//		Name of the mesh
	;//	pMesh
	;//		Pointer to the mesh object if basic polygon data found
	;//	pPMesh
	;//		Pointer to the progressive mesh object if progressive mesh data found
	;//	pPatchMesh
	;//		Pointer to the patch mesh object if patch data found
	;//	pMaterials
	;//		Array of materials used in the mesh
	;//	pEffectInstances
	;//		Array of effect instances used in the mesh
	;//	NumMaterials
	;//		Num elements in the pMaterials array
	;//	pAdjacency
	;//		Adjacency array for the mesh
	;//	pSkinInfo
	;//		Pointer to the skininfo object if the mesh is skinned
	;//	pBoneNames
	;//		Array of names, one for each bone in the skinned mesh. 
	;//		The numberof bones can be found from the pSkinMesh object
	;//	pBoneOffsetMatrices
	;//		Array of matrices, one for each bone in the skinned mesh.
	;//
	;//------------------------------------------------------------------------

	&CastName&_CreateMeshContainer		comethod9 ?

	;//------------------------------------------------------------------------
	;// DestroyFrame:
	;// -------------
	;// Requests de-allocation of a frame object.
	;//
	;// Parameters:
	;//  pFrameToFree
	;//		Pointer to the frame to be de-allocated
	;//
	;//------------------------------------------------------------------------

	&CastName&_DestroyFrame			comethod2 ?

	;//------------------------------------------------------------------------
	;// DestroyMeshContainer:
	;// ---------------------
	;// Requests de-allocation of a mesh container object.
	;//
	;// Parameters:
	;//  pMeshContainerToFree
	;//		Pointer to the mesh container object to be de-allocated
	;//
	;//------------------------------------------------------------------------

	&CastName&_DestroyMeshContainer		comethod2 ?
ENDM

ID3DXAllocateHierarchy struct
	_vtID3DXAllocateHierarchy	ID3DXAllocateHierarchy
ID3DXAllocateHierarchy ends

LPD3DXALLOCATEHIERARCHY		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// ID3DXLoadUserData:
;// ------------------
;// This interface is implemented by the application to load user data in a .X file
;// When user data is found, these callbacks will be used to allow the application
;// to load the data.
;//----------------------------------------------------------------------------

_vtID3DXLoadUserData MACRO CastName:REQ
	&CastName&_LoadTopLevelData		comethod2 ?
	&CastName&_LoadFrameChildData		comethod3 ?
	&CastName&_LoadMeshChildData		comethod3 ?
ENDM

ID3DXLoadUserData struct
	_vtID3DXLoadUserData	ID3DXLoadUserData
ID3DXLoadUserData ends

LPD3DXLOADUSERDATA		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// ID3DXSaveUserData:
;// ------------------
;// This interface is implemented by the application to save user data in a .X file
;// The callbacks are called for all data saved.  The user can then add any
;// child data objects to the object provided to the callback.
;//----------------------------------------------------------------------------

_vtID3DXSaveUserData MACRO CastName:REQ
	&CastName&_AddFrameChildData		comethod4 ?
	&CastName&_AddMeshChildData		comethod4 ?
	;// NOTE: this is called once per Save.  All top level objects should be added using the 
	;// provided interface.  One call adds objects before the frame hierarchy, the other after
	&CastName&_AddTopLevelDataObjectsPre	comethod2 ?
	&CastName&_AddTopLevelDataObjectsPost	comethod2 ?
	;// callbacks for the user to register and then save templates to the XFile
	&CastName&_RegisterTemplates		comethod2 ?
	&CastName&_SaveTemplates		comethod2 ?
ENDM

ID3DXSaveUserData struct
	_vtID3DXSaveUserData	ID3DXSaveUserData
ID3DXSaveUserData ends

LPD3DXSAVEUSERDATA		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// D3DXCALLBACK_SEARCH_FLAGS:
;// --------------------------
;// Flags that can be passed into ID3DXAnimationSet::GetCallback. 
;//----------------------------------------------------------------------------

D3DXCALLBACK_SEARCH_EXCLUDING_INITIAL_POSITION	equ 001h ;// exclude callbacks at the initial position from the search
D3DXCALLBACK_SEARCH_BEHIND_INITIAL_POSITION	equ 002h ;// reverse the callback search direction
D3DXCALLBACK_SEARCH_FORCE_DWORD			equ 7fffffffh

D3DXCALLBACK_SEARCH_FLAGS	typedef DWORD

;//----------------------------------------------------------------------------
;// ID3DXAnimationSet:
;// ------------------
;// This interface implements an animation set.
;//----------------------------------------------------------------------------

_vtID3DXAnimationSet MACRO CastName:REQ
	_vtIUnknown CastName
	;// Name
	&CastName&_GetName			comethod1 ?
	;// Period
	&CastName&_GetPeriod			comethod1 ?
	&CastName&_GetPeriodicPosition		comethod2 ?
	;// Animation names
	&CastName&_GetNumAnimations		comethod1 ?
	&CastName&_GetAnimationNameByIndex	comethod3 ?
	&CastName&_GetAnimationIndexByName	comethod3 ?
	;// SRT
	&CastName&_GetSRT			comethod6 ?
	;// Callbacks
	&CastName&_GetCallback			comethod5 ?
ENDM

ID3DXAnimationSet struct
	_vtID3DXAnimationSet	ID3DXAnimationSet
ID3DXAnimationSet ends

LPD3DXANIMATIONSET		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// D3DXPLAYBACK_TYPE:
;// ------------------
;// This enum defines the type of animation set loop modes.
;//----------------------------------------------------------------------------

D3DXPLAY_LOOP		equ 0
D3DXPLAY_ONCE		equ 1
D3DXPLAY_PINGPONG	equ 2
D3DXPLAY_FORCE_DWORD	equ 7fffffffh

D3DXPLAYBACK_TYPE	typedef DWORD

;//----------------------------------------------------------------------------
;// D3DXKEY_VECTOR3:
;// ----------------
;// This structure describes a vector key for use in keyframe animation.
;// It specifies a vector Value at a given Time. This is used for scale and
;// translation keys.
;//----------------------------------------------------------------------------

_D3DXKEY_VECTOR3 struct
	Time	FLOAT ?
	Value	D3DXVECTOR3 <?>
_D3DXKEY_VECTOR3 ends

D3DXKEY_VECTOR3		typedef _D3DXKEY_VECTOR3
LPD3DXKEY_VECTOR3	typedef PTR _D3DXKEY_VECTOR3

;//----------------------------------------------------------------------------
;// D3DXKEY_QUATERNION:
;// -------------------
;// This structure describes a quaternion key for use in keyframe animation.
;// It specifies a quaternion Value at a given Time. This is used for rotation
;// keys.
;//----------------------------------------------------------------------------

_D3DXKEY_QUATERNION struct
	Time	FLOAT ?
	Value	D3DXQUATERNION <?>
_D3DXKEY_QUATERNION ends 

D3DXKEY_QUATERNION	typedef _D3DXKEY_QUATERNION
LPD3DXKEY_QUATERNION	typedef PTR _D3DXKEY_QUATERNION

;//----------------------------------------------------------------------------
;// D3DXKEY_CALLBACK:
;// -----------------
;// This structure describes an callback key for use in keyframe animation.
;// It specifies a pointer to user data at a given Time. 
;//----------------------------------------------------------------------------

_D3DXKEY_CALLBACK struct
	Time		FLOAT ?
	pCallbackData	DWORD ?
_D3DXKEY_CALLBACK ends

D3DXKEY_CALLBACK	typedef _D3DXKEY_CALLBACK
LPD3DXKEY_CALLBACK	typedef PTR _D3DXKEY_CALLBACK

;//----------------------------------------------------------------------------
;// D3DXCOMPRESSION_FLAGS:
;// ----------------------
;// Flags that can be passed into ID3DXKeyframedAnimationSet::Compress. 
;//----------------------------------------------------------------------------

D3DXCOMPRESS_DEFAULT		equ 0
D3DXCOMPRESS_FORCE_DWORD	equ 7fffffffh

D3DXCOMPRESSION_FLAGS	typedef DWORD

;//----------------------------------------------------------------------------
;// ID3DXKeyframedAnimationSet:
;// ---------------------------
;// This interface implements a compressable keyframed animation set.
;//----------------------------------------------------------------------------

_vtID3DXKeyframedAnimationSet MACRO CastName:REQ
	_vtID3DXAnimationSet CastName
	;// Playback
	&CastName&_GetPlaybackType		comethod1 ?
	&CastName&_GetSourceTicksPerSecond	comethod1 ?
	;// Scale keys
	&CastName&_GetNumScaleKeys		comethod2 ?
	&CastName&_GetScaleKeys			comethod3 ?
	;// Rotation keys
	&CastName&_GetNumRotationKeys		comethod2 ?
	&CastName&_GetRotationKeys		comethod3 ?
	;// Translation keys
	&CastName&_GetNumTranslationKeys	comethod2 ?
	&CastName&_GetTranslationKeys		comethod3 ?
	;// Callback keys
	&CastName&_GetNumCallbackKeys		comethod1 ?
	&CastName&_GetCallbackKeys		comethod2 ?
	;// One-time animaton SRT keyframe registration
	&CastName&_RegisterAnimationSRTKeys	comethod8 ?
	;// Compression
	&CastName&_Compress			comethod5 ?
ENDM

ID3DXKeyframedAnimationSet struct
	_vtID3DXKeyframedAnimationSet	ID3DXKeyframedAnimationSet
ID3DXKeyframedAnimationSet ends

LPD3DXKEYFRAMEDANIMATIONSET		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// ID3DXCompressedAnimationSet:
;// ----------------------------
;// This interface implements a compressed keyframed animation set.
;//----------------------------------------------------------------------------

_vtID3DXCompressedAnimationSet MACRO CastName:REQ
	_vtID3DXAnimationSet CastName
	;// Playback
	&CastName&_GetPlaybackType		comethod1 ?
	&CastName&_GetSourceTicksPerSecond	comethod1 ?
	;// Scale keys
	&CastName&_GetCompressedData		comethod2 ?
	;// Callback keys
	&CastName&_GetNumCallbackKeys		comethod1 ?
	&CastName&_GetCallbackKeys		comethod2 ?
ENDM

ID3DXCompressedAnimationSet struct
	_vtID3DXCompressedAnimationSet	ID3DXCompressedAnimationSet
ID3DXCompressedAnimationSet ends

LPD3DXCOMPRESSEDANIMATIONSET		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// D3DXPRIORITY_TYPE:
;// ------------------
;// This enum defines the type of priority group that a track can be assigned to.
;//----------------------------------------------------------------------------

D3DXPRIORITY_LOW		equ 0 ;// This track should be blended with all low priority tracks before mixed with the high priority result
D3DXPRIORITY_HIGH		equ 1 ;// This track should be blended with all high priority tracks before mixed with the low priority result
D3DXPRIORITY_FORCE_DWORD 	equ 7fffffffh

D3DXPRIORITY_TYPE		typedef DWORD

;//----------------------------------------------------------------------------
;// D3DXTRACK_DESC:
;// ---------------
;// This structure describes the mixing information of an animation track. 
;// The mixing information consists of the current position, speed, and blending 
;// weight for the track.  The Flags field also specifies whether the track is 
;// low or high priority.  Tracks with the same priority are blended together
;// and then the two resulting values are blended using the priority blend factor.
;// A track also has an animation set (stored separately) associated with it.  
;//----------------------------------------------------------------------------

_D3DXTRACK_DESC struct
	Priority	D3DXPRIORITY_TYPE ?
	Weight		FLOAT ?
	Speed		FLOAT ?
	Position	QWORD ?
	Enable		BOOL ?
_D3DXTRACK_DESC ends

D3DXTRACK_DESC			typedef _D3DXTRACK_DESC
LPD3DXTRACK_DESC		typedef PTR _D3DXTRACK_DESC

;//----------------------------------------------------------------------------
;// D3DXEVENT_TYPE:
;// ---------------
;// This enum defines the type of events keyable via the animation controller.
;//----------------------------------------------------------------------------

D3DXEVENT_TRACKSPEED		equ 0
D3DXEVENT_TRACKWEIGHT		equ 1
D3DXEVENT_TRACKPOSITION		equ 2
D3DXEVENT_TRACKENABLE		equ 3
D3DXEVENT_PRIORITYBLEND		equ 4
D3DXEVENT_FORCE_DWORD		equ 7fffffffh

D3DXEVENT_TYPE			typedef DWORD

;//----------------------------------------------------------------------------
;// D3DXTRANSITION_TYPE:
;// --------------------
;// This enum defines the type of transtion performed on a event that 
;// transitions from one value to another.
;//----------------------------------------------------------------------------

D3DXTRANSITION_LINEAR		equ 0 ;// Linear transition from one value to the next
D3DXTRANSITION_EASEINEASEOUT	equ 1 ;// Ease-In Ease-Out spline transtion from one value to the next
D3DXTRANSITION_FORCE_DWORD	equ 7fffffffh

D3DXTRANSITION_TYPE		typedef DWORD

;//----------------------------------------------------------------------------
;// D3DXEVENT_DESC:
;// ---------------
;// This structure describes a animation controller event.
;// It gives the event's type, track (if the event is a track event), global 
;// start time, duration, transition method, and target value.
;//----------------------------------------------------------------------------

_D3DXEVENT_DESC struct
	dx_Type		D3DXEVENT_TYPE ?
	Track		UINT ?
	StartTime	QWORD ?
	Duration	QWORD ?
	Transition	D3DXTRANSITION_TYPE ?
	union
		Weight	FLOAT ?
		Speed		FLOAT ?
		Position	QWORD ?
		Enable		BOOL ?
	ends
_D3DXEVENT_DESC ends

D3DXEVENT_DESC			typedef _D3DXEVENT_DESC
LPD3DXEVENT_DESC		typedef PTR _D3DXEVENT_DESC

;//----------------------------------------------------------------------------
;// D3DXEVENTHANDLE:
;// ----------------
;// Handle values used to efficiently reference animation controller events.
;//----------------------------------------------------------------------------

D3DXEVENTHANDLE			typedef DWORD
LPD3DXEVENTHANDLE		typedef PTR D3DXEVENTHANDLE

;//----------------------------------------------------------------------------
;// ID3DXAnimationCallbackHandler:
;// ------------------------------
;// This interface is intended to be implemented by the application, and can
;// be used to handle callbacks in animation sets generated when 
;// ID3DXAnimationController::AdvanceTime() is called.  
;//----------------------------------------------------------------------------

_vtID3DXAnimationCallbackHandler MACRO CastName:REQ
	&CastName&_HandleCallback		comethod3 ?
ENDM

ID3DXAnimationCallbackHandler struct
	_vtID3DXAnimationCallbackHandler	ID3DXAnimationCallbackHandler
ID3DXAnimationCallbackHandler ends

LPD3DXANIMATIONCALLBACKHANDLER		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// ID3DXAnimationController:
;// -------------------------
;// This interface implements the main animation functionality. It connects
;// animation sets with the transform frames that are being animated. Allows
;// mixing multiple animations for blended animations or for transistions
;// It adds also has methods to modify blending parameters over time to 
;// enable smooth transistions and other effects.
;//-------------------------------------------------------------------------

_vtID3DXAnimationController MACRO CastName:REQ
	_vtIUnknown CastName
	;// Max sizes
	&CastName&_GetMaxNumAnimationOutputs		comethod1 ?
	&CastName&_GetMaxNumAnimationSets		comethod1 ?
	&CastName&_GetMaxNumTracks			comethod1 ?
	&CastName&_GetMaxNumEvents			comethod1 ?
	;// Animation output registration
	&CastName&_RegisterAnimationOutput		comethod6 ?
	;// Animation set registration
	&CastName&_RegisterAnimationSet			comethod2 ?
	&CastName&_UnregisterAnimationSet		comethod2 ?
	&CastName&_GetNumAnimationSets			comethod1 ?
	&CastName&_GetAnimationSet			comethod3 ?
	;// Global time
	&CastName&_AdvanceTime				comethod3 ?
	&CastName&_ResetTime				comethod1 ?
	&CastName&_GetTime				comethod1 ?
	;// Tracks
	&CastName&_SetTrackAnimationSet			comethod3 ?
	&CastName&_GetTrackAnimationSet			comethod3 ?
	&CastName&_SetTrackPriority			comethod3 ?
	&CastName&_SetTrackSpeed			comethod3 ?
	&CastName&_SetTrackWeight			comethod3 ?
	&CastName&_SetTrackPosition			comethod3 ?
	&CastName&_SetTrackEnable			comethod3 ?
	&CastName&_SetTrackDesc				comethod3 ?
	&CastName&_GetTrackDesc				comethod3 ?
	;// Priority blending
	&CastName&_SetPriorityBlend			comethod2 ?
	&CastName&_GetPriorityBlend			comethod1 ?
	;// Event keying
	&CastName&_KeyTrackSpeed			comethod6 ?
	&CastName&_KeyTrackWeight			comethod6 ?
	&CastName&_KeyTrackPosition			comethod4 ?
	&CastName&_KeyTrackEnable			comethod4 ?
	&CastName&_KeyPriorityBlend			comethod5 ?
	;// Event unkeying
	&CastName&_UnkeyEvent				comethod2 ?
	&CastName&_UnkeyAllTrackEvents			comethod2 ?
	&CastName&_UnkeyAllPriorityBlends		comethod1 ?
	;// Event enumeration
	&CastName&_GetCurrentTrackEvent			comethod3 ?
	&CastName&_GetCurrentPriorityBlend		comethod1 ?
	&CastName&_GetUpcomingTrackEvent		comethod3 ?
	&CastName&_GetUpcomingPriorityBlend		comethod2 ?
	&CastName&_ValidateEvent			comethod2 ?
	&CastName&_GetEventDesc				comethod3 ?
	;// Cloning
	&CastName&_CloneAnimationController		comethod6 ?
ENDM

ID3DXAnimationController struct
	_vtID3DXAnimationController	ID3DXAnimationController
ID3DXAnimationController ends

LPD3DXANIMATIONCONTROLLER		typedef PTR DWORD

;//----------------------------------------------------------------------------
;// D3DXLoadMeshHierarchyFromX:
;// ---------------------------
;// Loads the first frame hierarchy in a .X file.
;//
;// Parameters:
;//  Filename
;//      Name of the .X file
;//  MeshOptions
;//      Mesh creation options for meshes in the file (see d3dx9mesh.h)
;//  pD3DDevice
;//      D3D9 device on which meshes in the file are created in
;//  pAlloc
;//      Allocation interface used to allocate nodes of the frame hierarchy
;//  pUserDataLoader
;//      Application provided interface to allow loading of user data
;//  ppFrameHierarchy
;//      Returns root node pointer of the loaded frame hierarchy
;//  ppAnimController
;//      Returns pointer to an animation controller corresponding to animation
;//		in the .X file. This is created with default max tracks and events
;//
;//----------------------------------------------------------------------------

D3DXLoadMeshHierarchyFromXA		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXLoadMeshHierarchyFromXW		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXLoadMeshHierarchyFromX		equ D3DXLoadMeshHierarchyFromXW
else
D3DXLoadMeshHierarchyFromX		equ D3DXLoadMeshHierarchyFromXA
endif

D3DXLoadMeshHierarchyFromXInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXSaveMeshHierarchyToFile:
;// ----------------------------
;// Creates a .X file and saves the mesh hierarchy and corresponding animations
;// in it
;//
;// Parameters:
;//  Filename
;//      Name of the .X file
;//  XFormat
;//      Format of the .X file (text or binary, compressed or not, etc)
;//  pFrameRoot
;//      Root node of the hierarchy to be saved
;//  pAnimController
;//      The animation controller whose animation sets are to be stored
;//  pUserDataSaver
;//      Application provided interface to allow adding of user data to
;//        data objects saved to .X file
;//
;//----------------------------------------------------------------------------

D3DXSaveMeshHierarchyToFileA		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXSaveMeshHierarchyToFileW		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXSaveMeshHierarchyToFile		equ D3DXSaveMeshHierarchyToFileW
else
D3DXSaveMeshHierarchyToFile		equ D3DXSaveMeshHierarchyToFileA
endif

;//----------------------------------------------------------------------------
;// D3DXFrameDestroy:
;// -----------------
;// Destroys the subtree of frames under the root, including the root
;//
;// Parameters:
;//	pFrameRoot
;//		Pointer to the root node
;//  pAlloc
;//      Allocation interface used to de-allocate nodes of the frame hierarchy
;//
;//----------------------------------------------------------------------------

D3DXFrameDestroy			PROTO :DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXFrameAppendChild:
;// ---------------------
;// Add a child frame to a frame
;//
;// Parameters:
;//	pFrameParent
;//		Pointer to the parent node
;//  pFrameChild
;//      Pointer to the child node
;//
;//----------------------------------------------------------------------------

D3DXFrameAppendChild			PROTO :DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXFrameFind:
;// --------------
;// Finds a frame with the given name.  Returns NULL if no frame found.
;//
;// Parameters:
;//	pFrameRoot
;//		Pointer to the root node
;//  Name
;//      Name of frame to find
;//
;//----------------------------------------------------------------------------

D3DXFrameFind				PROTO :DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXFrameRegisterNamedMatrices:
;// -------------------------------
;// Finds all frames that have non-null names and registers each of those frame
;// matrices to the given animation controller
;//
;// Parameters:
;//	pFrameRoot
;//		Pointer to the root node
;//	pAnimController
;//		Pointer to the animation controller where the matrices are registered
;//
;//----------------------------------------------------------------------------

D3DXFrameRegisterNamedMatrices		PROTO :DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXFrameNumNamedMatrices:
;// --------------------------
;// Counts number of frames in a subtree that have non-null names 
;//
;// Parameters:
;//	pFrameRoot
;//		Pointer to the root node of the subtree
;// Return Value:
;//		Count of frames
;//
;//----------------------------------------------------------------------------

D3DXFrameNumNamedMatrices		PROTO :DWORD

;//----------------------------------------------------------------------------
;// D3DXFrameCalculateBoundingSphere:
;// ---------------------------------
;// Computes the bounding sphere of all the meshes in the frame hierarchy.
;//
;// Parameters:
;//	pFrameRoot
;//		Pointer to the root node
;//	pObjectCenter
;//		Returns the center of the bounding sphere
;//	pObjectRadius
;//		Returns the radius of the bounding sphere
;//
;//----------------------------------------------------------------------------

D3DXFrameCalculateBoundingSphere	PROTO :DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXCreateKeyframedAnimationSet:
;// --------------------------------
;// This function creates a compressable keyframed animations set interface.
;// 
;// Parameters:
;//  pName
;//      Name of the animation set
;//  TicksPerSecond
;//      Number of keyframe ticks that elapse per second
;//  Playback
;//      Playback mode of keyframe looping
;//  NumAnimations
;//      Number of SRT animations
;//  NumCallbackKeys
;//      Number of callback keys
;//  pCallbackKeys
;//      Array of callback keys
;//  ppAnimationSet
;//      Returns the animation set interface
;// 
;//-----------------------------------------------------------------------------		

D3DXCreateKeyframedAnimationSet		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD	

;//----------------------------------------------------------------------------
;// D3DXCreateCompressedAnimationSet:
;// --------------------------------
;// This function creates a compressed animations set interface from 
;// compressed data.
;// 
;// Parameters:
;//  pName
;//      Name of the animation set
;//  TicksPerSecond
;//      Number of keyframe ticks that elapse per second
;//  Playback
;//      Playback mode of keyframe looping
;//  pCompressedData
;//      Compressed animation SRT data
;//  NumCallbackKeys
;//      Number of callback keys
;//  pCallbackKeys
;//      Array of callback keys
;//  ppAnimationSet
;//      Returns the animation set interface
;// 
;//-----------------------------------------------------------------------------		

D3DXCreateCompressedAnimationSet	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD		

;//----------------------------------------------------------------------------
;// D3DXCreateAnimationController:
;// ------------------------------
;// This function creates an animation controller object.
;//
;// Parameters:
;//  MaxNumMatrices
;//      Maximum number of matrices that can be animated
;//  MaxNumAnimationSets
;//      Maximum number of animation sets that can be played
;//  MaxNumTracks
;//      Maximum number of animation sets that can be blended
;//  MaxNumEvents
;//      Maximum number of outstanding events that can be scheduled at any given time
;//  ppAnimController
;//      Returns the animation controller interface
;//
;//-----------------------------------------------------------------------------		

D3DXCreateAnimationController		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

endif	;//__D3DX9ANIM_H__
