;//////////////////////////////////////////////////////////////////////////////
;//
;//  Copyright (C) Microsoft Corporation.  All Rights Reserved.
;//
;//  File:       d3dx9mesh.inc
;//  Content:    D3DX mesh types and functions
;//
;//  Translated to .ASM by: Siekmanski
;//
;//////////////////////////////////////////////////////////////////////////////

ifndef __D3DX9MESH_H__
__D3DX9MESH_H__ equ 1

include dxfile.inc	;// defines LPDIRECTXFILEDATA

;// {4F5621A3-7F25-46dc-8239-820B823795CB}
IID_ID3DXBaseMesh	TEXTEQU <{04f5621a3h,07f25h,046dch,{082h,039h,082h,00bh,082h,037h,095h,0cbh}}>

;// {29E3EB8D-4DD6-4524-B1A2-1EF0581E778D}
IID_ID3DXMesh		TEXTEQU <{029e3eb8dh,04dd6h,04524h,{0b1h,0a2h,01eh,0f0h,058h,01eh,077h,08dh}}>

;// {1da4801f-a26e-4623-bd5471ff57f4bd02}
IID_ID3DXPMesh 		TEXTEQU <{01da4801fh,0a26eh,04623h,{0bdh,054h,071h,0ffh,057h,0f4h,0bdh,002h}}>

;// {1C4E77C5-8391-4951-A019-D4C5A9539EEC}
IID_ID3DXSPMesh 	TEXTEQU <{01c4e77c5h,08391h,04951h,{0a0h,019h,0d4h,0c5h,0a9h,053h,09eh,0ech}}>

;// {0E7DBBF3-421A-4dd8-B738-A5DAC3A48767}
IID_ID3DXSkinInfo	TEXTEQU <{00e7dbbf3h,0421ah,04dd8h,{0b7h,038h,0a5h,0dah,0c3h,0a4h,087h,067h}}>

;// {0AD3E8BC-290D-4dc7-91AB-73A82755B13E}
IID_ID3DXPatchMesh	TEXTEQU <{00ad3e8bch,0290dh,04dc7h,{091h,0abh,073h,0a8h,027h,055h,0b1h,03eh}}>

;//patch mesh can be quads or tris
D3DXPATCHMESH_RECT		equ 01h
D3DXPATCHMESH_TRI		equ 02h
D3DXPATCHMESH_NPATCH		equ 03h
D3DXPATCHMESH_FORCE_DWORD	equ 07fffffffh ;/* force 32-bit size enum */

D3DXPATCHMESHTYPE		typedef DWORD

;// Mesh options - lower 3 bytes only, upper byte used by _D3DXMESHOPT option flags
D3DXMESH_32BIT			equ 000001h ;// If set, then use 32 bit indices, if not set use 16 bit indices.
D3DXMESH_DONOTCLIP		equ 000002h ;// Use D3DUSAGE_DONOTCLIP for VB & IB.
D3DXMESH_POINTS			equ 000004h ;// Use D3DUSAGE_POINTS for VB & IB. 
D3DXMESH_RTPATCHES		equ 000008h ;// Use D3DUSAGE_RTPATCHES for VB & IB. 
D3DXMESH_NPATCHES		equ 004000h ;// Use D3DUSAGE_NPATCHES for VB & IB. 
D3DXMESH_VB_SYSTEMMEM		equ 000010h ;// Use D3DPOOL_SYSTEMMEM for VB. Overrides D3DXMESH_MANAGEDVERTEXBUFFER
D3DXMESH_VB_MANAGED		equ 000020h ;// Use D3DPOOL_MANAGED for VB. 
D3DXMESH_VB_WRITEONLY		equ 000040h ;// Use D3DUSAGE_WRITEONLY for VB.
D3DXMESH_VB_DYNAMIC		equ 000080h ;// Use D3DUSAGE_DYNAMIC for VB.
D3DXMESH_VB_SOFTWAREPROCESSING	equ 008000h ;// Use D3DUSAGE_SOFTWAREPROCESSING for VB.
D3DXMESH_IB_SYSTEMMEM		equ 000100h ;// Use D3DPOOL_SYSTEMMEM for IB. Overrides D3DXMESH_MANAGEDINDEXBUFFER
D3DXMESH_IB_MANAGED		equ 000200h ;// Use D3DPOOL_MANAGED for IB.
D3DXMESH_IB_WRITEONLY		equ 000400h ;// Use D3DUSAGE_WRITEONLY for IB.
D3DXMESH_IB_DYNAMIC		equ 000800h ;// Use D3DUSAGE_DYNAMIC for IB.
D3DXMESH_IB_SOFTWAREPROCESSING	equ 010000h ;// Use D3DUSAGE_SOFTWAREPROCESSING for IB.

D3DXMESH_VB_SHARE		equ 001000h ;// Valid for Clone* calls only, forces cloned mesh/pmesh to share vertex buffer

D3DXMESH_USEHWONLY		equ 002000h ;// Valid for ID3DXSkinInfo::ConvertToBlendedMesh

;    // Helper options
D3DXMESH_SYSTEMMEM		equ 000110h ;// D3DXMESH_VB_SYSTEMMEM | D3DXMESH_IB_SYSTEMMEM
D3DXMESH_MANAGED		equ 000220h ;// D3DXMESH_VB_MANAGED | D3DXMESH_IB_MANAGED
D3DXMESH_WRITEONLY		equ 000440h ;// D3DXMESH_VB_WRITEONLY | D3DXMESH_IB_WRITEONLY
D3DXMESH_DYNAMIC		equ 000880h ;// D3DXMESH_VB_DYNAMIC | D3DXMESH_IB_DYNAMIC
D3DXMESH_SOFTWAREPROCESSING	equ 018000h ;// D3DXMESH_VB_SOFTWAREPROCESSING | D3DXMESH_IB_SOFTWAREPROCESSING

;//patch mesh options
D3DXPATCHMESH_DEFAULT		equ 000h

;// option field values for specifying min value in D3DXGeneratePMesh and D3DXSimplifyMesh
D3DXMESHSIMP_VERTEX		equ 001h
D3DXMESHSIMP_FACE		equ 002h
MAX_FVF_DECL_SIZE		equ MAXD3DDECLLENGTH + 1 ;// +1 for END

_D3DXATTRIBUTERANGE struct
	AttribId	DWORD ?
	FaceStart	DWORD ?
	FaceCount	DWORD ?
	VertexStart	DWORD ?
	VertexCount	DWORD ?
_D3DXATTRIBUTERANGE ends

D3DXATTRIBUTERANGE 	typedef _D3DXATTRIBUTERANGE
LPD3DXATTRIBUTERANGE	typedef PTR _D3DXATTRIBUTERANGE

_D3DXMATERIAL struct
	MatD3D		D3DMATERIAL9 <>
	pTextureFilename DWORD ?
_D3DXMATERIAL ends

D3DXMATERIAL		typedef _D3DXMATERIAL 
LPD3DXMATERIAL		typedef PTR _D3DXMATERIAL 

D3DXEDT_STRING		equ 001h ;// pValue points to a null terminated ASCII string 
D3DXEDT_FLOATS		equ 002h ;// pValue points to an array of floats - number of floats is NumBytes / sizeof(float)
D3DXEDT_DWORD		equ 003h ;// pValue points to a DWORD
D3DXEDT_FORCEDWORD	equ 07fffffffh

D3DXEFFECTDEFAULTTYPE	typedef DWORD

_D3DXEFFECTDEFAULT struct
	pParamName	dword ?
	dx_Type		D3DXEFFECTDEFAULTTYPE ? ;// type of the data pointed to by pValue
	NumBytes	DWORD ? ;// size in bytes of the data pointed to by pValue
	pValue		DWORD ? ;// data for the default of the effect
_D3DXEFFECTDEFAULT ends

D3DXEFFECTDEFAULT	typedef _D3DXEFFECTDEFAULT
LPD3DXEFFECTDEFAULT	typedef PTR _D3DXEFFECTDEFAULT

_D3DXEFFECTINSTANCE struct
	pEffectFilename	DWORD ?
	NumDefaults	DWORD ?
	pDefaults	LPD3DXEFFECTDEFAULT ?
_D3DXEFFECTINSTANCE ends

D3DXEFFECTINSTANCE	typedef _D3DXEFFECTINSTANCE
LPD3DXEFFECTINSTANCE	typedef PTR _D3DXEFFECTINSTANCE

_D3DXATTRIBUTEWEIGHTS struct
	Position	FLOAT ?
	Boundary	FLOAT ?
	Normal		FLOAT ?
	Diffuse		FLOAT ?
	Specular	FLOAT ?
	Texcoord	FLOAT 8 dup (?)
	Tangent		FLOAT ?
	Binormal	FLOAT ?
_D3DXATTRIBUTEWEIGHTS ends

D3DXATTRIBUTEWEIGHTS	typedef _D3DXATTRIBUTEWEIGHTS
LPD3DXATTRIBUTEWEIGHTS	typedef PTR _D3DXATTRIBUTEWEIGHTS

D3DXWELDEPSILONS_WELDALL		equ 1 ;// weld all vertices marked by adjacency as being overlapping
D3DXWELDEPSILONS_WELDPARTIALMATCHES	equ 2 ;// if a given vertex component is within epsilon, modify partial matched 
					      ;// vertices so that both components identical AND if all components "equal"
					      ;// remove one of the vertices
D3DXWELDEPSILONS_DONOTREMOVEVERTICES	equ 4 ;// instructs weld to only allow modifications to vertices and not removal
					      ;// ONLY valid if D3DXWELDEPSILONS_WELDPARTIALMATCHES is set
					      ;// useful to modify vertices to be equal, but not allow vertices to be removed
D3DXWELDEPSILONS_DONOTSPLIT		equ 8 ;// instructs weld to specify the D3DXMESHOPT_DONOTSPLIT flag when doing an Optimize(ATTR_SORT)
					      ;// if this flag is not set, all vertices that are in separate attribute groups
					      ;// will remain split and not welded.  Setting this flag can slow down software vertex processing

_D3DXWELDEPSILONS struct
	Position	FLOAT ? ;// NOTE: This does NOT replace the epsilon in GenerateAdjacency
				;// in general, it should be the same value or greater than the one passed to GeneratedAdjacency
	BlendWeights	FLOAT ?
	Normal		FLOAT ?
	PSize		FLOAT ?
	Specular	FLOAT ?
	Diffuse		FLOAT ?
	Texcoord	FLOAT 8 dup (?)
	Tangent		FLOAT ?
	Binormal	FLOAT ?
	TessFactor	FLOAT ?
_D3DXWELDEPSILONS ends

D3DXWELDEPSILONS	typedef _D3DXWELDEPSILONS
LPD3DXWELDEPSILONS	typedef PTR _D3DXWELDEPSILONS

;marinus

_vtID3DXBaseMesh MACRO CastName:REQ
	_vtIUnknown CastName
	&CastName&_DrawSubset		comethod2 ?
	&CastName&_GetNumFaces		comethod1 ?
	&CastName&_GetNumVertices	comethod1 ?
	&CastName&_GetFVF		comethod1 ?
	&CastName&_GetDeclaration	comethod2 ?
	&CastName&_GetOptions		comethod1 ?
	&CastName&_GetDevice		comethod2 ?
	&CastName&_CloneMeshFVF		comethod5 ?
	&CastName&_CloneMesh		comethod5 ?
	&CastName&_GetVertexBuffer	comethod2 ?
	&CastName&_GetIndexBuffer	comethod2 ?
	&CastName&_LockVertexBuffer	comethod3 ?
	&CastName&_UnlockVertexBuffer	comethod1 ?
	&CastName&_LockIndexBuffer	comethod3 ?
	&CastName&_UnlockIndexBuffer	comethod1 ?
	&CastName&_GetAttributeTable	comethod3 ?
        &CastName&_ConvertPointRepsToAdjacency comethod3 ?
        &CastName&_ConvertAdjacencyToPointReps comethod3 ?
        &CastName&_GenerateAdjacency	comethod3 ?
        &CastName&_UpdateSemantics	comethod2 ?
ENDM

ID3DXBaseMesh struct
	_vtID3DXBaseMesh	ID3DXBaseMesh
ID3DXBaseMesh ends

LPD3DXBASEMESH		typedef PTR DWORD 

_vtID3DXMesh MACRO CastName:REQ
	_vtID3DXBaseMesh CastName
	&CastName&_LockAttributeBuffer		comethod3 ?
	&CastName&_UnlockAttributeBuffer	comethod1 ?
	&CastName&_Optimize			comethod7 ?
	&CastName&_OptimizeInplace		comethod6 ?
	&CastName&_SetAttributeTable		comethod3 ?
ENDM

ID3DXMesh struct
	_vtID3DXMesh	ID3DXMesh
ID3DXMesh ends

LPD3DXMESH		typedef PTR DWORD 

_vtID3DXPMesh MACRO CastName:REQ
	_vtID3DXBaseMesh CastName
	&CastName&_ClonePMeshFVF	comethod5 ?
	&CastName&_ClonePMesh		comethod5 ?
	&CastName&_SetNumFaces		comethod2 ?
	&CastName&_SetNumVertices	comethod2 ?
	&CastName&_GetMaxFaces		comethod1 ?
	&CastName&_GetMinFaces		comethod1 ?
	&CastName&_GetMaxVertices	comethod1 ?
	&CastName&_GetMinVertices	comethod1 ?
	&CastName&_Save			comethod5 ?
	&CastName&_Optimize		comethod6 ?
	&CastName&_OptimizeBaseLOD	comethod3 ?
	&CastName&_TrimByFaces		comethod5 ?
	&CastName&_TrimByVertices	comethod5 ?
	&CastName&_GetAdjacency		comethod2 ?
	;//  Used to generate the immediate "ancestor" for each vertex when it is removed by a vsplit.  Allows generation of geomorphs
	;//     Vertex buffer must be equal to or greater than the maximum number of vertices in the pmesh
	&CastName&_GenerateVertexHistory comethod2 ?
ENDM

ID3DXPMesh struct
	_vtID3DXPMesh	ID3DXPMesh
ID3DXPMesh ends

LPD3DXPMESH		typedef PTR DWORD 

_vtID3DXSPMesh MACRO CastName:REQ
	_vtIUnknown CastName
	&CastName&_GetNumFaces		comethod1 ?
	&CastName&_GetNumVertices	comethod1 ?
	&CastName&_GetFVF		comethod1 ?
	&CastName&_GetDeclaration	comethod2 ?
	&CastName&_GetOptions		comethod1 ?
	&CastName&_GetDevice		comethod2 ?
	&CastName&_CloneMeshFVF		comethod7 ?
	&CastName&_CloneMesh		comethod7 ?
	&CastName&_ClonePMeshFVF	comethod7 ?
	&CastName&_ClonePMesh		comethod7 ?
	&CastName&_ReduceFaces		comethod2 ?
	&CastName&_ReduceVertices	comethod2 ?
	&CastName&_GetMaxFaces		comethod1 ?
	&CastName&_GetMaxVertices	comethod1 ?
	&CastName&_GetVertexAttributeWeights comethod2 ?
	&CastName&_GetVertexWeights	comethod2 ?
ENDM

ID3DXSPMesh struct
	_vtID3DXSPMesh	ID3DXSPMesh
ID3DXSPMesh ends

LPD3DXSPMESH		typedef PTR DWORD 

UNUSED16 equ (0ffffh)
UNUSED32 equ (0ffffffffh)

;// ID3DXMesh::Optimize options - upper byte only, lower 3 bytes used from _D3DXMESH option flags
D3DXMESHOPT_COMPACT		equ 001000000h
D3DXMESHOPT_ATTRSORT		equ 002000000h
D3DXMESHOPT_VERTEXCACHE		equ 004000000h
D3DXMESHOPT_STRIPREORDER	equ 008000000h
D3DXMESHOPT_IGNOREVERTS		equ 010000000h ;// optimize faces only, don't touch vertices
D3DXMESHOPT_DONOTSPLIT		equ 020000000h ;// do not split vertices shared between attribute groups when attribute sorting
D3DXMESHOPT_DEVICEINDEPENDENT	equ 000400000h ;// Only affects VCache.  uses a static known good cache size for all cards                            
;// D3DXMESHOPT_SHAREVB has been removed, please use D3DXMESH_VB_SHARE instead

;// Subset of the mesh that has the same attribute and bone combination.
;// This subset can be rendered in a single draw call
_D3DXBONECOMBINATION struct
	AttribId	DWORD ?
	FaceStart	DWORD ?
	FaceCount	DWORD ?
	VertexStart	DWORD ?
	VertexCount	DWORD ?
	BoneId		DWORD ?
_D3DXBONECOMBINATION ends

D3DXBONECOMBINATION		typedef _D3DXBONECOMBINATION 
LPD3DXBONECOMBINATION		typedef PTR _D3DXBONECOMBINATION 

;// The following types of patch combinations are supported:
;// Patch type   Basis       Degree
;// Rect         Bezier      2,3,5
;// Rect         B-Spline    2,3,5
;// Rect         Catmull-Rom 3
;// Tri          Bezier      2,3,5
;// N-Patch      N/A         3

_D3DXPATCHINFO struct
	PatchType	D3DXPATCHMESHTYPE ?
	Degree		D3DDEGREETYPE ?
	Basis		D3DBASISTYPE ?
_D3DXPATCHINFO ends

D3DXPATCHINFO			typedef _D3DXPATCHINFO 
LPD3DXPATCHINFO			typedef PTR _D3DXPATCHINFO 

_vtID3DXPatchMesh MACRO CastName:REQ
	_vtIUnknown CastName
	&CastName&_GetNumPatches	comethod1 ?
	&CastName&_GetNumVertices	comethod1 ?
	&CastName&_GetDeclaration	comethod2 ?
	&CastName&_GetControlVerticesPerPatch comethod1 ?
	&CastName&_GetOptions		comethod1 ?
	&CastName&_GetDevice		comethod2 ?
	&CastName&_GetPatchInfo		comethod2 ?
	;// Control mesh access    
	&CastName&_GetVertexBuffer	comethod2 ?
	&CastName&_GetIndexBuffer	comethod2 ?
	&CastName&_LockVertexBuffer	comethod3 ?
	&CastName&_UnlockVertexBuffer	comethod1 ?
	&CastName&_LockIndexBuffer	comethod3 ?
	&CastName&_UnlockIndexBuffer	comethod1 ?
	&CastName&_LockAttributeBuffer	comethod3 ?
	&CastName&_UnlockAttributeBuffer comethod1 ?

	;// This function returns the size of the tessellated mesh given a tessellation level.
	;// This assumes uniform tessellation. For adaptive tessellation the Adaptive parameter must
	;// be set to TRUE and TessellationLevel should be the max tessellation.
	;// This will result in the max mesh size necessary for adaptive tessellation.    
	&CastName&_GetTessSize		comethod5 ?

	;//GenerateAdjacency determines which patches are adjacent with provided tolerance
	;//this information is used internally to optimize tessellation
	&CastName&_GenerateAdjacency	comethod2 ?

	;//CloneMesh Creates a new patchmesh with the specified decl, and converts the vertex buffer
	;//to the new decl. Entries in the new decl which are new are set to 0. If the current mesh
	;//has adjacency, the new mesh will also have adjacency
	&CastName&_CloneMesh		comethod4 ?

	;// Optimizes the patchmesh for efficient tessellation. This function is designed
	;// to perform one time optimization for patch meshes that need to be tessellated
	;// repeatedly by calling the Tessellate() method. The optimization performed is
	;// independent of the actual tessellation level used.
	;// Currently Flags is unused.
	;// If vertices are changed, Optimize must be called again
	&CastName&_Optimize		comethod2 ?

	;//gets and sets displacement parameters
	;//displacement maps can only be 2D textures MIP-MAPPING is ignored for non adapative tessellation
	&CastName&_SetDisplaceParam	comethod7 ?
	&CastName&_GetDisplaceParam	comethod7 ?

	;// Performs the uniform tessellation based on the tessellation level. 
	;// This function will perform more efficiently if the patch mesh has been optimized using the Optimize() call.
	&CastName&_Tessellate		comethod3 ?

	;// Performs adaptive tessellation based on the Z based adaptive tessellation criterion.
	;// pTrans specifies a 4D vector that is dotted with the vertices to get the per vertex
	;// adaptive tessellation amount. Each edge is tessellated to the average of the criterion
	;// at the 2 vertices it connects.
	;// MaxTessLevel specifies the upper limit for adaptive tesselation.
	;// This function will perform more efficiently if the patch mesh has been optimized using the Optimize() call.
	&CastName&_TessellateAdaptive	comethod4 ?
ENDM

ID3DXPatchMesh struct
	_vtID3DXPatchMesh	ID3DXPatchMesh
ID3DXPatchMesh ends

LPD3DXPATCHMESH		typedef PTR DWORD 

_vtID3DXSkinInfo MACRO CastName:REQ
	_vtIUnknown CastName
	&CastName&_SetBoneInfluence		comethod5 ?
	&CastName&_GetNumBoneInfluences		comethod2 ?
	&CastName&_GetBoneInfluence		comethod4 ?
	&CastName&_GetMaxVertexInfluences	comethod2 ?
	&CastName&_GetNumBones			comethod1 ?

	;// This gets the max face influences based on a triangle mesh with the specified index buffer
	&CastName&_GetMaxFaceInfluences		comethod4 ?

	;// Set min bone influence. Bone influences that are smaller than this are ignored
	&CastName&_SetMinBoneInfluence		comethod2 ?

	;// Get min bone influence. 
	&CastName&_GetMinBoneInfluence		comethod1 ?

	;// Bone names are returned by D3DXLoadSkinMeshFromXof. They are not used by any other method of this object
 	&CastName&_SetBoneName			comethod3 ?
	&CastName&_GetBoneName			comethod2 ?

	;// Bone offset matrices are returned by D3DXLoadSkinMeshFromXof. They are not used by any other method of this object
	&CastName&_SetBoneOffsetMatrix		comethod3 ?
	&CastName&_GetBoneOffsetMatrix		comethod2 ?

	;// Clone a skin info object
	&CastName&_Clone			comethod2 ?

	;// Update bone influence information to match vertices after they are reordered. This should be called 
	;// if the target vertex buffer has been reordered externally.
	&CastName&_Remap			comethod3 ?

	;// These methods enable the modification of the vertex layout of the vertices that will be skinned
	&CastName&_SetFVF			comethod2 ?
	&CastName&_SetDeclaration		comethod2 ?
	&CastName&_GetFVF			comethod1 ?
	&CastName&_GetDeclaration		comethod2 ?

	;// Apply SW skinning based on current pose matrices to the target vertices.
	&CastName&_UpdateSkinnedMesh		comethod5 ?

	;// Takes a mesh and returns a new mesh with per vertex blend weights and a bone combination
	;// table that describes which bones affect which subsets of the mesh
	&CastName&_ConvertToBlendedMesh		comethod11 ?

	;// Takes a mesh and returns a new mesh with per vertex blend weights and indices 
	;// and a bone combination table that describes which bones palettes affect which subsets of the mesh
	&CastName&_ConvertToIndexedBlendedMesh	comethod12 ?
ENDM

ID3DXSkinInfo struct
	_vtID3DXSkinInfo	ID3DXSkinInfo
ID3DXSkinInfo ends

LPD3DXSKININFO		typedef PTR DWORD 

D3DXCreateMesh			PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateMeshFVF		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCreateSPMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;// clean a mesh up for simplification, try to make manifold
D3DXCleanMesh			PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXValidMesh			PROTO :DWORD,:DWORD,:DWORD
D3DXGeneratePMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXSimplifyMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXComputeBoundingSphere 	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXComputeBoundingBox		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXComputeNormals		PROTO :DWORD,:DWORD
D3DXCreateBuffer		PROTO :DWORD,:DWORD

D3DXLoadMeshFromXA		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXLoadMeshFromXW		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXLoadMeshFromX	equ D3DXLoadMeshFromXW
else
D3DXLoadMeshFromX	equ D3DXLoadMeshFromXA
endif

D3DXLoadMeshFromXInMemory	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXLoadMeshFromXResource	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

D3DXSaveMeshToXA		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXSaveMeshToXW		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXSaveMeshToX		equ D3DXSaveMeshToXW
else
D3DXSaveMeshToX		equ D3DXSaveMeshToXA
endif

D3DXCreatePMeshFromStream	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;// Creates a skin info object based on the number of vertices, number of bones, and a declaration describing the vertex layout of the target vertices
;// The bone names and initial bone transforms are not filled in the skin info object by this method.
D3DXCreateSkinInfo		PROTO :DWORD,:DWORD,:DWORD,:DWORD

;// Creates a skin info object based on the number of vertices, number of bones, and a FVF describing the vertex layout of the target vertices
;// The bone names and initial bone transforms are not filled in the skin info object by this method.
D3DXCreateSkinInfoFVF		PROTO :DWORD,:DWORD,:DWORD,:DWORD

D3DXLoadMeshFromXof		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;// This similar to D3DXLoadMeshFromXof, except also returns skinning info if present in the file
;// If skinning info is not present, ppSkinInfo will be NULL     
D3DXLoadSkinMeshFromXof		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;// The inverse of D3DXConvertTo{Indexed}BlendedMesh() functions. It figures out the skinning info from
;// the mesh and the bone combination table and populates a skin info object with that data. The bone
;// names and initial bone transforms are not filled in the skin info object by this method. This works
;// with either a non-indexed or indexed blended mesh. It examines the FVF or declarator of the mesh to
;// determine what type it is.
D3DXCreateSkinInfoFromBlendedMesh	PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXTessellateNPatches			PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
					;// if false use linear intrep for normals, if true use quadratic

;//generates implied outputdecl from input decl
;//the decl generated from this should be used to generate the output decl for
;//the tessellator subroutines. 
D3DXGenerateOutputDecl		PROTO :DWORD,:DWORD

;//loads patches from an XFileData
;//since an X file can have up to 6 different patch meshes in it,
;//returns them in an array - pNumPatches will contain the number of
;//meshes in the actual file. 
D3DXLoadPatchMeshFromXof	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//computes the size a single rect patch.
D3DXRectPatchSize		PROTO :DWORD,:DWORD,:DWORD

;//computes the size of a single triangle patch      
D3DXTriPatchSize		PROTO :DWORD,:DWORD,:DWORD

;//tessellates a patch into a created mesh
;//similar to D3D RT patch
D3DXTessellateRectPatch		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXTessellateTriPatch		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//creates an NPatch PatchMesh from a D3DXMESH 
D3DXCreateNPatchMesh		PROTO :DWORD,:DWORD

;//creates a patch mesh
D3DXCreatePatchMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//returns the number of degenerates in a patch mesh -
;//text output put in string.
D3DXValidPatchMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXGetFVFVertexSize		PROTO :DWORD
D3DXGetDeclVertexSize		PROTO :DWORD,:DWORD
D3DXGetDeclLength		PROTO :DWORD
D3DXDeclaratorFromFVF		PROTO :DWORD,:DWORD
D3DXFVFFromDeclarator		PROTO :DWORD,:DWORD
D3DXWeldVertices		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

_D3DXINTERSECTINFO struct
	FaceIndex	DWORD ? ;// index of face intersected
	U		FLOAT ? ;// Barycentric Hit Coordinates    
	V		FLOAT ? ;// Barycentric Hit Coordinates
	Dist		FLOAT ? ;// Ray-Intersection Parameter Distance
_D3DXINTERSECTINFO ends

D3DXINTERSECTINFO	typedef _D3DXINTERSECTINFO
LPD3DXINTERSECTINFO	typedef PTR _D3DXINTERSECTINFO

D3DXIntersect		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXIntersectSubset	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXSplitMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXIntersectTri	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXSphereBoundProbe	PROTO :DWORD,:DWORD,:DWORD,:DWORD
D3DXBoxBoundProbe	PROTO :DWORD,:DWORD,:DWORD,:DWORD

;//D3DXComputeTangent
;//
;//Computes the Tangent vectors for the TexStage texture coordinates
;//and places the results in the TANGENT[TangentIndex] specified in the meshes' DECL
;//puts the binorm in BINORM[BinormIndex] also specified in the decl.
;//
;//If neither the binorm or the tangnet are in the meshes declaration,
;//the function will fail. 
;//
;//If a tangent or Binorm field is in the Decl, but the user does not
;//wish D3DXComputeTangent to replace them, then D3DX_DEFAULT specified
;//in the TangentIndex or BinormIndex will cause it to ignore the specified 
;//semantic.
;//
;//Wrap should be specified if the texture coordinates wrap.

D3DXComputeTangent			PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXConvertMeshSubsetToSingleStrip	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXConvertMeshSubsetToStrips		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
        
;//============================================================================
;//
;//  D3DXOptimizeFaces:
;//  --------------------
;//  Generate a face remapping for a triangle list that more effectively utilizes
;//    vertex caches.  This optimization is identical to the one provided
;//    by ID3DXMesh::Optimize with the hardware independent option enabled.
;//
;//  Parameters:
;//   pbIndices
;//      Triangle list indices to use for generating a vertex ordering
;//   NumFaces
;//      Number of faces in the triangle list
;//   NumVertices
;//      Number of vertices referenced by the triangle list
;//   b32BitIndices
;//      TRUE if indices are 32 bit, FALSE if indices are 16 bit
;//   pFaceRemap
;//      Destination buffer to store face ordering
;//      The number stored for a given element is where in the new ordering
;//        the face will have come from.  See ID3DXMesh::Optimize for more info.
;//
;//============================================================================

D3DXOptimizeFaces		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD
        
;//============================================================================
;//
;//  D3DXOptimizeVertices:
;//  --------------------
;//  Generate a vertex remapping to optimize for in order use of vertices for 
;//    a given set of indices.  This is commonly used after applying the face
;//    remap generated by D3DXOptimizeFaces
;//
;//  Parameters:
;//   pbIndices
;//      Triangle list indices to use for generating a vertex ordering
;//   NumFaces
;//      Number of faces in the triangle list
;//   NumVertices
;//      Number of vertices referenced by the triangle list
;//   b32BitIndices
;//      TRUE if indices are 32 bit, FALSE if indices are 16 bit
;//   pVertexRemap
;//      Destination buffer to store vertex ordering
;//      The number stored for a given element is where in the new ordering
;//        the vertex will have come from.  See ID3DXMesh::Optimize for more info.
;//
;//============================================================================

D3DXOptimizeVertices		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//===========================================================================
;//
;//  Data structures for Spherical Harmonic Precomputation
;//
;//
;//============================================================================


D3DXSHCQUAL_FASTLOWQUALITY	equ 1
D3DXSHCQUAL_SLOWHIGHQUALITY	equ 2
D3DXSHCQUAL_FORCE_DWORD		equ 07fffffffh

D3DXSHCOMPRESSQUALITYTYPE	typedef DWORD

;// for all properties that are colors the red channel is used
;// if the simulator is run with bSpectral FALSE

_D3DXSHMATERIAL struct
	Diffuse		D3DCOLORVALUE <?> ;// Diffuse albedo of the surface.  (Ignored if object is a Mirror)
	bMirror		BOOL ?		;// Must be set to FALSE.  bMirror == TRUE not currently supported
	bSubSurf	BOOL ?		;// true if the object does subsurface scattering - can't do this and be a mirror
	;// subsurface scattering parameters 
	RelativeIndexOfRefraction	FLOAT ?
	Absorption		D3DCOLORVALUE <?>
	ReducedScattering	D3DCOLORVALUE <?>
_D3DXSHMATERIAL ends

D3DXSHMATERIAL			typedef _D3DXSHMATERIAL

_D3DXSHPRTBUFFER_DESC struct
	NumSamples	UINT ? ;// number of texels or vertices sampled
	Order		UINT ? ;// order of spherical harmonics used 
	NumChannels	UINT ?
	dx_Width	UINT ?
	dx_Height	UINT ?
_D3DXSHPRTBUFFER_DESC ends

D3DXSHPRTBUFFER_DESC		typedef _D3DXSHPRTBUFFER_DESC

_D3DXSHPRTCOMPBUFFER_DESC struct
	SampleSize	UINT ?
	NumSamples	UINT ? ;// number of texels or vertices sampled
	NumClusters	UINT ?
	NumPCA		UINT ?                    
	Order		UINT ? ;// order of spherical harmonics used 
	NumChannels	UINT ?
_D3DXSHPRTCOMPBUFFER_DESC ends

D3DXSHPRTCOMPBUFFER_DESC	typedef _D3DXSHPRTCOMPBUFFER_DESC

;// allocated in D3DXSHPRTCompSplitMeshSC
;// vertices are duplicated into multiple super clusters but
;// only have a valid status in one super cluster (fill in the rest)

_D3DXSHPRTSPLITMESHVERTDATA struct
	uVertRemap	UINT ? ;// vertex in original mesh this corresponds to
	uSubCluster	UINT ? ;// cluster index relative to super cluster
	ucVertStatus	UCHAR ? ;// 1 if vertex has valid data, 0 if it is "fill"
_D3DXSHPRTSPLITMESHVERTDATA ends

D3DXSHPRTSPLITMESHVERTDATA	typedef _D3DXSHPRTSPLITMESHVERTDATA

;// used in D3DXSHPRTCompSplitMeshSC
;// information for each super cluster that maps into face/vert arrays

_D3DXSHPRTSPLITMESHCLUSTERDATA struct
	uVertStart	UINT ? ;// initial index into remapped vertex array
	uVertLength	UINT ? ;// number of vertices in this super cluster
	uFaceStart	UINT ? ;// initial index into face array
	uFaceLength	UINT ? ;// number of faces in this super cluster
	uClusterStart	UINT ? ;// initial index into cluster array
	uClusterLength	UINT ? ;// number of clusters in this super cluster
_D3DXSHPRTSPLITMESHCLUSTERDATA ends

D3DXSHPRTSPLITMESHCLUSTERDATA	typedef _D3DXSHPRTSPLITMESHCLUSTERDATA

;// call back function for simulator
;// return S_OK to keep running the simulator - anything else represents
;// failure and the simulator will abort.

;(WINAPI *LPD3DXSHPRTSIMCB) (float fPercentDone);
LPD3DXSHPRTSIMCB	typedef PTR DWORD

;//===========================================================================
;//
;//  Spherical Harmonic Precomputation Routines
;//
;// NOTE:
;//  * These functions are intended for offline use, extraction routines can
;//    be used at load time, but the simulators and compressor should only be
;//    used when authoring content. 
;//
;//============================================================================

;//============================================================================
;//
;//  D3DXSHPRTSimulation:
;//  --------------------
;//  Runs the PRT simulation on a set of input meshes using a corresponding 
;//  set of materials.  This function can take a long time to run and should 
;//  only done offline.
;//
;//  Parameters:
;//   Order
;//      Order of SH to use, generates Order^2 coeffs (Degree is Order - 1)
;//   NumMeshes
;//      Number of meshes in the scene, where each mesh has a unique material
;//   ppScene
;//      Meshes that represent the scene
;//   ppMaterials
;//      Materials for each corresponding mesh
;//   NumRays
;//      Number of rays to shoot at each vertex
;//   NumBounces
;//      Number of bounces simulated - if this is not zero inter-reflections 
;//      are computed
;//   EnableSubSurf
;//      Indicates whether or not Subsurface Scattering is to be used
;//   LengthScale
;//      Scale used for subsurface scattering (1 would be a 1mm cube)
;//   EnableSpectral
;//      TRUE enables color bleeding by computing RGB transfer vectors
;//      FALSE just uses the red channel for material properties
;//   ppSimulationResults
;//      Buffer that is allocated and filled in by the simulator
;//   pProgressCallback
;//      Optional function pointer that is called periodically
;//      Must return S_OK or simulator exits
;//
;//============================================================================

D3DXSHPRTSimulation	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTExtractChannel:
;//  ------------------------
;//  Pulls the data for a given channel out of pSimulationResults
;//
;//  Parameters:
;//   Order
;//      Order of spherical harmonic coefficients to extract
;//   pTransferCoefficients
;//      Array of Order^2 floats into which transfer coefficients for the 
;//      specified channel are written
;//   Channel
;//      Specifies the channel to extract (0/1/2 for R/G/B)
;//   pSimulationResults
;//      Buffer obtained from D3DXSHPRTSimulation
;//
;//============================================================================

D3DXSHPRTExtractChannel		PROTO :DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTGetRawDataPointer:
;//  ---------------------------
;//  Given a buffer that has been simulated, makes ppData reference the
;//  raw data in the buffer.  This pointer is invalid after the buffer
;//  has been released.  The data is formatted as follows:
;//      FLOAT fRawData[NumSamples][NumChannels][Order*Order]
;//  where NumSamples is the number of texels/vertices in the scene.
;//
;//  Parameters:
;//   pSimulationResults
;//      Buffer obtained from the simulator that contains transfer vectors
;//   ppRawData
;//      Returns a pointer to the raw data inside the buffer
;//
;//============================================================================

D3DXSHPRTGetRawDataPointer	PROTO :DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTExtractDesc:
;//  ---------------------
;//  Given the result of a PRT simulation, this function extracts its
;//  description.
;//
;//  Parameters:
;//   pSimulationResults
;//      Buffer obtained from the simulator
;//   pDesc
;//      Structure to be filled in with information from the buffer
;//      Width/Height non-zero only if the textured simulator was used
;//
;//============================================================================

D3DXSHPRTExtractDesc		PROTO :DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTSimulationTex:
;//  -----------------------
;//  Runs the PRT simulation on an input mesh in texture space.  
;//  Returns a buffer that contains PRT results for every texel.
;//  This function can take a long time to run and should only done offline.
;//
;//  Parameters:
;//   Order
;//      Order of SH to use, generates Order^2 coeffs per channel per texel
;//   pScene
;//      Mesh that represents the scene
;//   pMaterial
;//      Material which specifies the albedo for the scene (if no albedo 
;//      texture was specified), and the subsurface scattering properties
;//   NumRays
;//      Number of rays to shoot at each texel
;//   NumBounces
;//      Number of bounces simulated - if this is not zero inter-reflections 
;//      are computed
;//   EnableSubSurf
;//      Indicates whether or not subsurface scattering is to be used
;//   LengthScale
;//      Scale used for subsurface scattering (1 would be a 1mm cube)
;//   EnableSpectral
;//      TRUE enables color bleeding by computing RGB transfer vectors
;//      FALSE just uses the red channel for material properties
;//   ppSimulationResults
;//      Buffer that is allocated and filled in by the simulator
;//   Width
;//      Number of texels to sample across horizontally;//   Height
;//      Number of texels to sample across vertically
;//   pAlbedoTexture
;//      Albedo (diffuse reflectance) of surface (can be NULL)
;//   pProgressCallback
;//      Optional function pointer that is called periodically  
;//      (must return S_OK or simulator exits)
;//
;//============================================================================

D3DXSHPRTSimulationTex		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTExtractTexture:
;//  ------------------------
;//  Pulls the data for a given channel out of pSimulationResults.  
;//  
;//  Parameters:
;//   Channel
;//      Channel to be extracted.
;//   StartCoefficient
;//      Initial coefficient to extract 
;//   NumCoefficients
;//      Number of coefficients to extract
;//   pSimulationResults
;//      Buffer obtained from D3DXSHPRTSimulationTex
;//   pTexture
;//      Texture where data will be stored - must match dimensions specified
;//      when simulator was run and be a signed or float format
;//
;//  Example:
;//      For an order 4 simulation, there are 16 coefficients, which can be 
;//      stored into four 4-channel textures by calling D3DXSPHRTExtractTexture 
;//      4 times with NumCoefficients set to 4, and StartCoefficient set to 
;//      0, 4, 8, and 12 in succession.
;//
;//============================================================================

D3DXSHPRTExtractTexture		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTExtractToMesh:
;//  -----------------------
;//  Pulls transfer coefficients from the buffer containing the simulation 
;//  results and attaches them to the input mesh.
;//  Can only be called on single channel buffers (use D3DXSHPRTExtractChannel 
;//  otherwise).
;//
;//  Parameters:
;//   Order
;//      Order of SH to use, generates Order^2 coeffs, degree is Order-1
;//   pScene
;//      Single mesh that data is going to be packed into
;//   pSimulationResults
;//      Buffer obtained from D3DXSHPRTSimulation
;//   Usage
;//      D3DDECLUSAGE where coefficients are to be stored
;//   UsageIndexStart
;//      Starting index for coefficients to be stored
;//
;//============================================================================

D3DXSHPRTExtractToMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompress:
;//  ------------------
;//  This function compresses a PRT buffer, generating a new compressed
;//  buffer.
;//
;//  Parameters:
;//   Order
;//      Order of SH to compress, generates Order^2 coeffs, degree is Order-1
;//   pSimulationResults
;//      Buffer obtained from the simulator that contains transfer vectors.
;//   Quality
;//      Type of compression to use 
;//   NumClusters
;//      Number of clusters to use for compression
;//   NumPCA
;//      Number of PCA vectors to use in each cluster
;//   ppCompressedResults
;//      Returns the compressed data
;//
;//============================================================================

D3DXSHPRTCompress		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompExtractToMesh:
;//  ---------------------------
;//  Pulls PCA coefficients from compressed buffer and attaches them to the 
;//  mesh.
;//
;//  Parameters:
;//   NumPCA
;//      Number of PCA coefficients to extract
;//   pScene
;//      Single mesh that data is going to be packed into
;//   pCompressedResults
;//      Buffer obtained from D3DXSHPRTCompress
;//   Usage
;//      D3DDECLUSAGE where coefficients are to be stored
;//   UsageIndexStart
;//      Starting index for coefficients to be stored
;//
;//============================================================================

D3DXSHPRTCompExtractToMesh		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompExtractDesc:
;//  -------------------------
;//  Given a compressed buffer, extracts a description of the data.
;//
;//  Parameters:
;//   pCompressedResults
;//      Buffer obtained D3DXSHPRTCompress
;//   pDesc
;//      Structure to be filled in with information from the buffer
;//
;//============================================================================

D3DXSHPRTCompExtractDesc		PROTO :DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompNormalizeData:
;//  ---------------------------
;//  Given a compressed buffer, rescales all of the PCA projection coefficients
;//  so that they are within [-1, 1].  The PCA vectors are scaled so that 
;//  reconstruction is still correct.  This maximizes precision when packing
;//  into textures.
;//
;//  Parameters:
;//   pCompressedResults
;//      Buffer obtained from D3DXSHPRTCompress
;//
;//============================================================================

D3DXSHPRTCompNormalizeData		PROTO :DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompExtractBasis:
;//  --------------------------
;//  Extracts the mean + PCA basis vectors for a given cluster from a
;//  compressed buffer.  The data is laid out in memory:
;//      FLOAT fData[NumSamples][NumChannels][Order*Order]
;//  Where NumSamples/NumChannels/Order are from the D3DXSHPRTCOMPBUFFER_DESC
;//  that can be extracted from pBuffer.
;//
;//  Parameters:
;//   Cluster
;//      Cluster whose basis is going to be extracted
;//   pCompressedResults
;//      Buffer obtained from D3DXSHPRTCompress
;//   pClusterBasis
;//      Array of floats into which cluster basis is written
;//
;//============================================================================

D3DXSHPRTCompExtractBasis	PROTO :DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompExtractClusterIDs:
;//  -------------------------------
;//  Extracts the per sample cluster ID from a compressed data set.
;//
;//  Parameters:
;//   pCompressedResults
;//      Buffer obtained from D3DXSHPRTCompress
;//   pClusterIDs
;//      Pointer where D3DXSHPRTCOMPBUFFER_DESC::NumSamples IDs are written 
;//
;//============================================================================

D3DXSHPRTCompExtractClusterIDs	PROTO :DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompExtractPCA:
;//  ------------------------
;//  Extracts the per-sample PCA coefficients from a compressed buffer.
;//
;//  Parameters:
;//   StartPCA
;//      Starting PCA projection coefficient to extract
;//   NumExtract
;//      Number of PCA projection coefficients to extract
;//   pCompressedResults
;//      Buffer obtained from D3DXSHPRTCompress
;//   pPCACoefficients
;//      Pointer where NumSamples * NumPCA PCA coefficients are written 
;//
;//============================================================================

D3DXSHPRTCompExtractPCA		PROTO :DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompExtractTexture:
;//  ----------------------------
;//  Extracts the per sample PCA coefficients from a compressed data set.  They
;//  are extracted into a texture that has already been allocated.
;//
;//  Parameters:
;//   StartPCA
;//      Starting PCA projection coefficient to extract
;//   NumExtract
;//      Number of PCA projection coefficients to extract
;//   pCompressedResults
;//      Buffer obtained from D3DXSHPRTCompress
;//   pTexture
;//      Texture where data is stored - must match dimensions of simulator
;//      and be a signed or floating point format
;//
;//============================================================================

D3DXSHPRTCompExtractTexture	PROTO :DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompSuperCluster:
;//  --------------------------
;//  Used with compressed results of D3DXSHPRTSimulation.
;//  Generates "super clusters" - groups of clusters that can be drawn in
;//  the same draw call.  A greedy algorithm that minimizes overdraw is used
;//  to group the clusters.
;//
;//  Parameters:
;//   pClusterIDs
;//      NumVerts cluster ID's (extracted from a compressed buffer)
;//   pScene
;//      Mesh that represents composite scene passed to the simulator
;//   MaxNumClusters
;//      Maximum number of clusters allocated per super cluster
;//   NumClusters
;//      Number of clusters computed in the simulator
;//   pSuperClusterIDs
;//      Array of length NumClusters, contains index of super cluster
;//      that corresponding cluster was assigned to
;//   pNumSuperClusters
;//      Returns the number of super clusters allocated
;//      
;//============================================================================

D3DXSHPRTCompSuperCluster	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//============================================================================
;//
;//  D3DXSHPRTCompSplitMeshSC:
;//  -------------------------
;//  Used with compressed results of the vertex version of the PRT simulator.
;//  After D3DXSHRTCompSuperCluster has been called this function can be used
;//  to split the mesh into a group of faces/vertices per super cluster.
;//  Each super cluster contains all of the faces that contain any vertex
;//  classified in one of its clusters.  All of the vertices connected to this
;//  set of faces are also included with the returned array ppVertStatus 
;//  indicating whether or not the vertex belongs to the supercluster.
;//
;//  Parameters:
;//   pClusterIDs
;//      NumVerts cluster ID's (extracted from a compressed buffer)
;//   NumVertices
;//      Number of vertices in original mesh
;//   NumClusters
;//      Number of clusters (input parameter to compression)
;//   pSuperClusterIDs
;//      Array of size NumClusters that will contain super cluster ID's (from
;//      D3DXSHCompSuerCluster)
;//   NumSuperClusters
;//      Number of superclusters allocated in D3DXSHCompSuerCluster
;//   pInputIB
;//      Raw index buffer for mesh - format depends on bInputIBIs32Bit
;//   InputIBIs32Bit
;//      Indicates whether the input index buffer is 32-bit (otherwise 16-bit
;//      is assumed)
;//   NumFaces
;//      Number of faces in the original mesh (pInputIB is 3 times this length)
;//   ppIBData
;//      Raw index buffer that will contain the resulting split faces.  Format
;//      determined by bIBIs32Bit.  Allocated by function
;//   pIBDataLength
;//      Length of ppIBData, assigned in function
;//   OutputIBIs32Bit
;//      Indicates whether the output index buffer is to be 32-bit (otherwise 
;//      16-bit is assumed)
;//   ppFaceRemap
;//      Mapping of each face in ppIBData to original faces.  Length is
;//      *pIBDataLength/3.  Allocated in function
;//   ppVertData
;//      New vertex data structure.  Size of pVertDataLength
;//   pVertDataLength
;//      Number of new vertices in split mesh.  Assigned in function
;//   pSCClusterList
;//      Array of length NumClusters which pSCData indexes into (Cluster* fields)
;//      for each SC, contains clusters sorted by super cluster
;//   pSCData
;//      Structure per super cluster - contains indices into ppIBData,
;//      pSCClusterList and ppVertData
;//
;//============================================================================

D3DXSHPRTCompSplitMeshSC	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//////////////////////////////////////////////////////////////////////////////
;//
;//  Definitions of .X file templates used by mesh load/save functions 
;//    that are not RM standard
;//
;//////////////////////////////////////////////////////////////////////////////

;// {3CF169CE-FF7C-44ab-93C0-F78F62D172E2}
DXFILEOBJ_XSkinMeshHeader		TEXTEQU <{03cf169ceh,0ff7ch,044abh,{093h,0c0h,0f7h,08fh,062h,0d1h,072h,0e2h}}>

;// {B8D65549-D7C9-4995-89CF-53A9A8B031E3}
DXFILEOBJ_VertexDuplicationIndices	TEXTEQU <{0b8d65549h,0d7c9h,04995h,{089h,0cfh,053h,0a9h,0a8h,0b0h,031h,0e3h}}>

;// {A64C844A-E282-4756-8B80-250CDE04398C}
DXFILEOBJ_FaceAdjacency			TEXTEQU <{0a64c844ah,0e282h,04756h,{08bh,080h,025h,00ch,0deh,004h,039h,08ch}}>

;// {6F0D123B-BAD2-4167-A0D0-80224F25FABB}
DXFILEOBJ_SkinWeights			TEXTEQU <{06f0d123bh,0bad2h,04167h,{0a0h,0d0h,080h,022h,04fh,025h,0fah,0bbh}}>

;// {A3EB5D44-FC22-429d-9AFB-3221CB9719A6}
DXFILEOBJ_Patch				TEXTEQU <{0a3eb5d44h,0fc22h,0429dh,{09ah,0fbh,032h,021h,0cbh,097h,019h,0a6h}}>

;// {D02C95CC-EDBA-4305-9B5D-1820D7704BBF}
DXFILEOBJ_PatchMesh			TEXTEQU <{0d02c95cch,0edbah,04305h,{09bh,05dh,018h,020h,0d7h,070h,04bh,0bfh}}>

;// {B9EC94E1-B9A6-4251-BA18-94893F02C0EA}
DXFILEOBJ_PatchMesh9			TEXTEQU <{0b9ec94e1h,0b9a6h,04251h,{0bah,018h,094h,089h,03fh,002h,0c0h,0eah}}>

;// {B6C3E656-EC8B-4b92-9B62-681659522947}
DXFILEOBJ_PMInfo			TEXTEQU <{0b6c3e656h,0ec8bh,04b92h,{09bh,062h,068h,016h,059h,052h,029h,047h}}>

;// {917E0427-C61E-4a14-9C64-AFE65F9E9844}
DXFILEOBJ_PMAttributeRange		TEXTEQU <{0917e0427h,0c61eh,04a14h,{09ch,064h,0afh,0e6h,05fh,09eh,098h,044h}}>

;// {574CCC14-F0B3-4333-822D-93E8A8A08E4C}
DXFILEOBJ_PMVSplitRecord		TEXTEQU <{0574ccc14h,0f0b3h,04333h,{082h,02dh,093h,0e8h,0a8h,0a0h,08eh,04ch}}>

;// {B6E70A0E-8EF9-4e83-94AD-ECC8B0C04897}
DXFILEOBJ_FVFData			TEXTEQU <{0b6e70a0eh,08ef9h,04e83h,{094h,0adh,0ech,0c8h,0b0h,0c0h,048h,097h}}>

;// {F752461C-1E23-48f6-B9F8-8350850F336F}
DXFILEOBJ_VertexElement			TEXTEQU <{0f752461ch,01e23h,048f6h,{0b9h,0f8h,083h,050h,085h,00fh,033h,06fh}}>

;// {BF22E553-292C-4781-9FEA-62BD554BDD93}
DXFILEOBJ_DeclData			TEXTEQU <{0bf22e553h,0292ch,04781h,{09fh,0eah,062h,0bdh,055h,04bh,0ddh,093h}}>

;// {F1CFE2B3-0DE3-4e28-AFA1-155A750A282D}
DXFILEOBJ_EffectFloats			TEXTEQU <{0f1cfe2b3h,00de3h,04e28h,{0afh,0a1h,015h,05ah,075h,00ah,028h,02dh}}>

;// {D55B097E-BDB6-4c52-B03D-6051C89D0E42}
DXFILEOBJ_EffectString			TEXTEQU <{0d55b097eh,0bdb6h,04c52h,{0b0h,03dh,060h,051h,0c8h,09dh,00eh,042h}}>

;// {622C0ED0-956E-4da9-908A-2AF94F3CE716}
DXFILEOBJ_EffectDWord			TEXTEQU <{0622c0ed0h,0956eh,04da9h,{090h,08ah,02ah,0f9h,04fh,03ch,0e7h,016h}}>

;// {3014B9A0-62F5-478c-9B86-E4AC9F4E418B}
DXFILEOBJ_EffectParamFloats		TEXTEQU <{03014b9a0h,062f5h,0478ch,{09bh,086h,0e4h,0ach,09fh,04eh,041h,08bh}}>

;// {1DBC4C88-94C1-46ee-9076-2C28818C9481}
DXFILEOBJ_EffectParamString		TEXTEQU <{01dbc4c88h,094c1h,046eeh,{090h,076h,02ch,028h,081h,08ch,094h,081h}}>

;// {E13963BC-AE51-4c5d-B00F-CFA3A9D97CE5}
DXFILEOBJ_EffectParamDWord		TEXTEQU <{0e13963bch,0ae51h,04c5dh,{0b0h,00fh,0cfh,0a3h,0a9h,0d9h,07ch,0e5h}}>

;// {E331F7E4-0559-4cc2-8E99-1CEC1657928F}
DXFILEOBJ_EffectInstance		TEXTEQU <{0e331f7e4h,00559h,04cc2h,{08eh,099h,01ch,0ech,016h,057h,092h,08fh}}>

;// {9E415A43-7BA6-4a73-8743-B73D47E88476}
DXFILEOBJ_AnimTicksPerSecond		TEXTEQU <{09e415a43h,07ba6h,04a73h,{087h,043h,0b7h,03dh,047h,0e8h,084h,076h}}>

endif ;//__D3DX9MESH_H__
