;//////////////////////////////////////////////////////////////////////////////
;//
;//  Copyright (c) Microsoft Corporation.  All rights reserved.
;//
;//  File:       d3dx9shader.inc
;//  Content:    D3DX Shader APIs
;//
;//  Translated to .ASM by: Siekmanski
;//
;//////////////////////////////////////////////////////////////////////////////

ifndef __D3DX9SHADER_H__
__D3DX9SHADER_H__ equ 1

;//---------------------------------------------------------------------------
;// D3DXTX_VERSION:
;// --------------
;// Version token used to create a procedural texture filler in effects
;// Used by D3DXFill[]TX functions
;//---------------------------------------------------------------------------

D3DXTX_VERSION MACRO _Major:REQ,_Minor:REQ
	EXITM %(('T' shl 24) or ('X' shl 16) or ((_Major) shl 8) or (_Minor))
ENDM

;//----------------------------------------------------------------------------
;// D3DXSHADER flags:
;// -----------------
;// D3DXSHADER_DEBUG
;//   Insert debug file/line/type/symbol information.
;//
;// D3DXSHADER_SKIPVALIDATION
;//   Do not validate the generated code against known capabilities and
;//   constraints.  This option is only recommended when compiling shaders
;//   you KNOW will work.  (ie. have compiled before without this option.)
;//   Shaders are always validated by D3D before they are set to the device.
;//
;// D3DXSHADER_SKIPOPTIMIZATION (valid for D3DXCompileShader calls only)
;//   Instructs the compiler to skip optimization steps during code generation.
;//   Unless you are trying to isolate a problem in your code, and suspect the
;//   compiler, using this option is not recommended.
;//
;// D3DXSHADER_PACKMATRIX_ROWMAJOR
;//   Unless explicitly specified, matrices will be packed in row-major order
;//   on input and output from the shader.
;//
;// D3DXSHADER_PACKMATRIX_COLUMNMAJOR
;//   Unless explicitly specified, matrices will be packed in column-major 
;//   order on input and output from the shader.  This is generally more 
;//   efficient, since it allows vector-matrix multiplication to be performed
;//   using a series of dot-products.
;//
;// D3DXSHADER_PARTIAL_PRECISION
;//   Force all computations in resulting shader to occur at partial precision.
;//   This may result in faster evaluation of shaders on some hardware.
;//
;// D3DXSHADER_FORCE_VS_SOFTWARE_NOOPT
;//   Force compiler to compile against the next highest available software
;//   target for vertex shaders.  This flag also turns optimizations off, 
;//   and debugging on.
;//
;// D3DXSHADER_FORCE_PS_SOFTWARE_NOOPT
;//   Force compiler to compile against the next highest available software
;//   target for pixel shaders.  This flag also turns optimizations off, 
;//   and debugging on.
;//
;//----------------------------------------------------------------------------

D3DXSHADER_DEBUG			equ (1 shl 0)
D3DXSHADER_SKIPVALIDATION		equ (1 shl 1)
D3DXSHADER_SKIPOPTIMIZATION		equ (1 shl 2)
D3DXSHADER_PACKMATRIX_ROWMAJOR		equ (1 shl 3)
D3DXSHADER_PACKMATRIX_COLUMNMAJOR	equ (1 shl 4)
D3DXSHADER_PARTIALPRECISION		equ (1 shl 5)
D3DXSHADER_FORCE_VS_SOFTWARE_NOOPT	equ (1 shl 6)
D3DXSHADER_FORCE_PS_SOFTWARE_NOOPT	equ (1 shl 7)

;//----------------------------------------------------------------------------
;// D3DXHANDLE:
;// -----------
;// Handle values used to efficiently reference shader and effect parameters.
;// Strings can be used as handles.  However, handles are not always strings.
;//----------------------------------------------------------------------------

D3DXHANDLE		typedef DWORD
LPD3DXHANDLE		typedef PTR D3DXHANDLE 

;//----------------------------------------------------------------------------
;// D3DXMACRO:
;// ----------
;// Preprocessor macro definition.  The application pass in a NULL-terminated
;// array of this structure to various D3DX APIs.  This enables the application
;// to #define tokens at runtime, before the file is parsed.
;//----------------------------------------------------------------------------

_D3DXMACRO struct
	Name		DWORD ?
	Definition	DWORD ?
_D3DXMACRO ends

D3DXMACRO		typedef _D3DXMACRO
LPD3DXMACRO		typedef PTR _D3DXMACRO

;//----------------------------------------------------------------------------
;// D3DXSEMANTIC:
;//----------------------------------------------------------------------------

_D3DXSEMANTIC struct
	Usage		UINT ?
	UsageIndex	UINT ?
_D3DXSEMANTIC ends

D3DXSEMANTIC		typedef _D3DXSEMANTIC
LPD3DXSEMANTIC		typedef PTR _D3DXSEMANTIC

;//----------------------------------------------------------------------------
;// D3DXFRAGMENT_DESC:
;//----------------------------------------------------------------------------

_D3DXFRAGMENT_DESC struct
	Name		DWORD ?
	Target		DWORD ?
_D3DXFRAGMENT_DESC ends

D3DXFRAGMENT_DESC	typedef _D3DXFRAGMENT_DESC
LPD3DXFRAGMENT_DESC	typedef PTR _D3DXFRAGMENT_DESC

;//----------------------------------------------------------------------------
;// D3DXREGISTER_SET:
;//----------------------------------------------------------------------------

D3DXRS_BOOL		equ 0
D3DXRS_INT4		equ 1
D3DXRS_FLOAT4		equ 2
D3DXRS_SAMPLER		equ 3
D3DXRS_FORCE_DWORD	equ 07fffffffh

D3DXREGISTER_SET	typedef DWORD
LPD3DXREGISTER_SET	typedef PTR DWORD

;//----------------------------------------------------------------------------
;// D3DXPARAMETER_CLASS:
;//----------------------------------------------------------------------------

D3DXPC_SCALAR		equ 0
D3DXPC_VECTOR		equ 1
D3DXPC_MATRIX_ROWS	equ 2
D3DXPC_MATRIX_COLUMNS	equ 3
D3DXPC_OBJECT		equ 4
D3DXPC_STRUCT		equ 5
D3DXPC_FORCE_DWORD	equ 07fffffffh

D3DXPARAMETER_CLASS	typedef DWORD
LPD3DXPARAMETER_CLASS	typedef PTR DWORD

;//----------------------------------------------------------------------------
;// D3DXPARAMETER_TYPE:
;//----------------------------------------------------------------------------

D3DXPT_VOID		equ 0
D3DXPT_BOOL		equ 1
D3DXPT_INT		equ 2
D3DXPT_FLOAT		equ 3
D3DXPT_STRING		equ 4
D3DXPT_TEXTURE		equ 5
D3DXPT_TEXTURE1D	equ 6
D3DXPT_TEXTURE2D	equ 7
D3DXPT_TEXTURE3D	equ 8
D3DXPT_TEXTURECUBE	equ 9
D3DXPT_SAMPLER		equ 10
D3DXPT_SAMPLER1D	equ 11
D3DXPT_SAMPLER2D	equ 12
D3DXPT_SAMPLER3D	equ 13
D3DXPT_SAMPLERCUBE	equ 14
D3DXPT_PIXELSHADER	equ 15
D3DXPT_VERTEXSHADER	equ 16
D3DXPT_PIXELFRAGMENT	equ 17
D3DXPT_VERTEXFRAGMENT	equ 18
D3DXPT_FORCE_DWORD	equ 07fffffffh

D3DXPARAMETER_TYPE	typedef DWORD
LPD3DXPARAMETER_TYPE	typedef PTR DWORD

;//----------------------------------------------------------------------------
;// D3DXCONSTANTTABLE_DESC:
;//----------------------------------------------------------------------------

_D3DXCONSTANTTABLE_DESC struct
	Creator		DWORD ? ;// Creator string
	Version		DWORD ? ;// Shader version
	Constants	UINT  ? ;// Number of constants
_D3DXCONSTANTTABLE_DESC ends

D3DXCONSTANTTABLE_DESC		typedef _D3DXCONSTANTTABLE_DESC
LPD3DXCONSTANTTABLE_DESC	typedef PTR _D3DXCONSTANTTABLE_DESC

;//----------------------------------------------------------------------------
;// D3DXCONSTANT_DESC:
;//----------------------------------------------------------------------------

_D3DXCONSTANT_DESC struct
	Name		DWORD ? ;// Constant name
	RegisterSet	D3DXREGISTER_SET ? ;// Register set=D3DXREGISTER_SET member
	RegisterIndex	UINT ? ;// Register index
	RegisterCount	UINT ? ;// Number of registers occupied

	dx_Class	D3DXPARAMETER_CLASS ? ;// Class=D3DXPARAMETER_CLASS member
	dx_Type		D3DXPARAMETER_TYPE ? ;// Component type=D3DXPARAMETER_TYPE member

	Rows		UINT ? ;// Number of rows
	Columns		UINT ? ;// Number of columns
	Elements	UINT ? ;// Number of array elements
	StructMembers	UINT ? ;// Number of structure member sub-parameters

	Bytes		UINT ? ;// Data size, in bytes
	DefaultValue	DWORD ? ;// Pointer to default value
_D3DXCONSTANT_DESC ends

D3DXCONSTANT_DESC	typedef _D3DXCONSTANT_DESC
LPD3DXCONSTANT_DESC	typedef PTR _D3DXCONSTANT_DESC

;//----------------------------------------------------------------------------
;// ID3DXConstantTable:
;//----------------------------------------------------------------------------

;// {9DCA3190-38B9-4fc3-92E3-39C6DDFB358B}
IID_ID3DXConstantTable	TEXTEQU <{09dca3190h,038b9h,04fc3h,{092h,0e3h,039h,0c6h,0ddh,0fbh,035h,08bh}}>

_vtID3DXConstantTable MACRO CastName:REQ
	_vtID3DXBuffer CastName
	;// Descs
	&CastName&_GetDesc			comethod2 ?
	&CastName&_GetConstantDesc		comethod4 ?
	;// Handle operations
	&CastName&_GetConstant			comethod3 ?
	&CastName&_GetConstantByName		comethod3 ?
	&CastName&_GetConstantElement		comethod3 ?
	;// Set Constants
	&CastName&_SetDefaults			comethod2 ?
	&CastName&_SetValue			comethod5 ?
	&CastName&_SetBool			comethod4 ?
	&CastName&_SetBoolArray			comethod5 ?
	&CastName&_SetInt			comethod4 ?
	&CastName&_SetIntArray			comethod5 ?
	&CastName&_SetFloat			comethod4 ?
	&CastName&_SetFloatArray		comethod5 ?
	&CastName&_SetVector			comethod4 ?
	&CastName&_SetVectorArray		comethod5 ?
	&CastName&_SetMatrix			comethod4 ?
	&CastName&_SetMatrixArray		comethod5 ?
	&CastName&_SetMatrixPointerArray	comethod5 ?
	&CastName&_SetMatrixTranspose		comethod4 ?
	&CastName&_SetMatrixTransposeArray	comethod5 ?
	&CastName&_SetMatrixTransposePointerArray comethod5 ?
ENDM

ID3DXConstantTable struct
	_vtID3DXConstantTable	ID3DXConstantTable
ID3DXConstantTable ends

LPD3DXCONSTANTTABLE	typedef PTR DWORD 

;//----------------------------------------------------------------------------
;// ID3DXFragmentLinker
;//----------------------------------------------------------------------------

;// {D59D3777-C973-4a3c-B4B0-2A62CD3D8B40}
IID_ID3DXFragmentLinker	TEXTEQU <{0d59d3777h,0c973h,04a3ch,{0b4h,0b0h,02ah,062h,0cdh,03dh,08bh,040h}}>


_vtID3DXFragmentLinker MACRO CastName:REQ
	_vtIUnknown CastName
	;// ID3DXFragmentLinker
    	;// fragment access and information retrieval functions
	&CastName&_GetDevice			comethod2 ?
	&CastName&_GetNumberOfFragments		comethod1 ?
	&CastName&_GetFragmentHandleByIndex	comethod2 ?
	&CastName&_GetFragmentHandleByName	comethod2 ?
	&CastName&_GetFragmentDesc		comethod3 ?
	;// add the fragments in the buffer to the linker
	&CastName&_AddFragments			comethod2 ?
	;// Create a buffer containing the fragments.  Suitable for saving to disk
	&CastName&_GetAllFragments		comethod2 ?
	&CastName&_GetFragment			comethod3 ?
	&CastName&_LinkShader			comethod7 ?
	&CastName&_LinkVertexShader		comethod7 ?
	&CastName&_LinkPixelShader		comethod7 ?
	&CastName&_ClearCache			comethod1 ?
ENDM

ID3DXFragmentLinker struct
	_vtID3DXFragmentLinker	ID3DXFragmentLinker
ID3DXFragmentLinker ends

LPD3DXFRAGMENTLINKER	typedef PTR DWORD 

;//----------------------------------------------------------------------------
;// D3DXINCLUDE_TYPE:
;//----------------------------------------------------------------------------

D3DXINC_LOCAL		equ 0
D3DXINC_SYSTEM		equ 1
D3DXINC_FORCE_DWORD	equ 07fffffffh

D3DXINCLUDE_TYPE	typedef DWORD
LPD3DXINCLUDE_TYPE	typedef PTR DWORD

;//----------------------------------------------------------------------------
;// ID3DXInclude:
;// -------------
;// This interface is intended to be implemented by the application, and can
;// be used by various D3DX APIs.  This enables application-specific handling
;// of #include directives in source files.
;//
;// Open()
;//    Opens an include file.  If successful, it should fill in ppData and
;//    pBytes.  The data pointer returned must remain valid until Close is
;//    subsequently called.
;// Close()
;//    Closes an include file.  If Open was successful, Close is guaranteed
;//    to be called before the API using this interface returns.
;//----------------------------------------------------------------------------

_vtID3DXInclude MACRO CastName:REQ
	&CastName&_Open		comethod6 ?
	&CastName&_Close	comethod2 ?
ENDM

ID3DXInclude struct
	_vtID3DXInclude	ID3DXInclude
ID3DXInclude ends

LPD3DXINCLUDE		typedef PTR DWORD

;//////////////////////////////////////////////////////////////////////////////
;// APIs //////////////////////////////////////////////////////////////////////
;//////////////////////////////////////////////////////////////////////////////

;//----------------------------------------------------------------------------
;// D3DXAssembleShader:
;// -------------------
;// Assembles a shader.
;//
;// Parameters:
;//  pSrcFile
;//      Source file name
;//  hSrcModule
;//      Module handle. if NULL, current module will be used
;//  pSrcResource
;//      Resource name in module
;//  pSrcData
;//      Pointer to source code
;//  SrcDataLen
;//      Size of source code, in bytes
;//  pDefines
;//      Optional NULL-terminated array of preprocessor macro definitions.
;//  pInclude
;//      Optional interface pointer to use for handling #include directives.
;//      If this parameter is NULL, #includes will be honored when assembling
;//      from file, and will error when assembling from resource or memory.
;//  Flags
;//      See D3DXSHADER_xxx flags
;//  ppShader
;//      Returns a buffer containing the created shader.  This buffer contains
;//      the assembled shader code, as well as any embedded debug info.
;//  ppErrorMsgs
;//      Returns a buffer containing a listing of errors and warnings that were
;//      encountered during assembly.  If you are running in a debugger,
;//      these are the same messages you will see in your debug output.
;//----------------------------------------------------------------------------

D3DXAssembleShaderFromFileA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXAssembleShaderFromFileW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXAssembleShaderFromFile	equ D3DXAssembleShaderFromFileW
else
D3DXAssembleShaderFromFile	equ D3DXAssembleShaderFromFileA
endif

D3DXAssembleShaderFromResourceA PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXAssembleShaderFromResourceW PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXAssembleShaderFromResource	equ D3DXAssembleShaderFromResourceW
else
D3DXAssembleShaderFromResource	equ D3DXAssembleShaderFromResourceA
endif

D3DXAssembleShader		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXCompileShader:
;// ------------------
;// Compiles a shader.
;//
;// Parameters:
;//  pSrcFile
;//      Source file name.
;//  hSrcModule
;//      Module handle. if NULL, current module will be used.
;//  pSrcResource
;//      Resource name in module.
;//  pSrcData
;//      Pointer to source code.
;//  SrcDataLen
;//      Size of source code, in bytes.
;//  pDefines
;//      Optional NULL-terminated array of preprocessor macro definitions.
;//  pInclude
;//      Optional interface pointer to use for handling #include directives.
;//      If this parameter is NULL, #includes will be honored when compiling
;//      from file, and will error when compiling from resource or memory.
;//  pFunctionName
;//      Name of the entrypoint function where execution should begin.
;//  pProfile
;//      Instruction set to be used when generating code.  Currently supported
;//      profiles are "vs_1_1", "vs_2_0", "vs_2_a", "vs_2_sw", "ps_1_1", 
;//      "ps_1_2", "ps_1_3", "ps_1_4", "ps_2_0", "ps_2_a", "ps_2_sw", "tx_1_0"
;//  Flags
;//      See D3DXSHADER_xxx flags.
;//  ppShader
;//      Returns a buffer containing the created shader.  This buffer contains
;//      the compiled shader code, as well as any embedded debug and symbol
;//      table info.  (See D3DXGetShaderConstantTable)
;//  ppErrorMsgs
;//      Returns a buffer containing a listing of errors and warnings that were
;//      encountered during the compile.  If you are running in a debugger,
;//      these are the same messages you will see in your debug output.
;//  ppConstantTable
;//      Returns a ID3DXConstantTable object which can be used to set
;//      shader constants to the device.  Alternatively, an application can
;//      parse the D3DXSHADER_CONSTANTTABLE block embedded as a comment within
;//      the shader.
;//----------------------------------------------------------------------------

D3DXCompileShaderFromFileA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCompileShaderFromFileW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCompileShaderFromFile	equ D3DXCompileShaderFromFileW
else
D3DXCompileShaderFromFile	equ D3DXCompileShaderFromFileA
endif

D3DXCompileShaderFromResourceA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXCompileShaderFromResourceW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXCompileShaderFromResource	equ D3DXCompileShaderFromResourceW
else
D3DXCompileShaderFromResource	equ D3DXCompileShaderFromResourceA
endif

D3DXCompileShader		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXGetPixelShaderProfile/D3DXGetVertexShaderProfile:
;// -----------------------------------------------------
;// Returns the name of the HLSL profile best suited to a given device.
;//
;// Parameters:
;//  pDevice
;//      Pointer to the device in question
;//----------------------------------------------------------------------------

D3DXGetPixelShaderProfile	PROTO :DWORD
D3DXGetVertexShaderProfile	PROTO :DWORD

;//----------------------------------------------------------------------------
;// D3DXFindShaderComment:
;// ----------------------
;// Searches through a shader for a particular comment, denoted by a FourCC in
;// the first DWORD of the comment.  If the comment is not found, and no other
;// error has occurred, S_FALSE is returned.
;//
;// Parameters:
;//  pFunction
;//      Pointer to the function DWORD stream
;//  FourCC
;//      FourCC used to identify the desired comment block.
;//  ppData
;//      Returns a pointer to the comment data (not including comment token
;//      and FourCC).  Can be NULL.
;//  pSizeInBytes
;//      Returns the size of the comment data in bytes.  Can be NULL.
;//----------------------------------------------------------------------------

D3DXFindShaderComment		PROTO :DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXGetShaderVersion:
;// -----------------------
;// Returns the shader version of a given shader.  Returns zero if the shader 
;// function is NULL.
;//
;// Parameters:
;//  pFunction
;//      Pointer to the function DWORD stream
;//----------------------------------------------------------------------------

D3DXGetShaderVersion		PROTO :DWORD

;//----------------------------------------------------------------------------
;// D3DXGetShaderSemantics:
;// -----------------------
;// Gets semantics for all input elements referenced inside a given shader.
;//
;// Parameters:
;//  pFunction
;//      Pointer to the function DWORD stream
;//  pSemantics
;//      Pointer to an array of D3DXSEMANTIC structures.  The function will
;//      fill this array with the semantics for each input element referenced
;//      inside the shader.  This array is assumed to contain at least
;//      MAXD3DDECLLENGTH elements.
;//  pCount
;//      Returns the number of elements referenced by the shader
;//----------------------------------------------------------------------------

D3DXGetShaderInputSemantics	PROTO :DWORD,:DWORD,:DWORD
D3DXGetShaderOutputSemantics	PROTO :DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXGetShaderSamplers:
;// ----------------------
;// Gets semantics for all input elements referenced inside a given shader.
;//
;// pFunction
;//      Pointer to the function DWORD stream
;// pSamplers
;//      Pointer to an array of LPCSTRs.  The function will fill this array
;//      with pointers to the sampler names contained within pFunction, for
;//      each sampler referenced inside the shader.  This array is assumed to
;//      contain at least 16 elements.
;// pCount
;//      Returns the number of samplers referenced by the shader
;//----------------------------------------------------------------------------

D3DXGetShaderSamplers		PROTO :DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXGetShaderConstantTable:
;// ---------------------------
;// Gets shader constant table embedded inside shader.  A constant table is
;// generated by D3DXAssembleShader and D3DXCompileShader, and is embedded in
;// the body of the shader.
;//
;// Parameters:
;//  pFunction
;//      Pointer to the function DWORD stream
;//  ppConstantTable
;//      Returns a ID3DXConstantTable object which can be used to set
;//      shader constants to the device.  Alternatively, an application can
;//      parse the D3DXSHADER_CONSTANTTABLE block embedded as a comment within
;//      the shader.
;//----------------------------------------------------------------------------

D3DXGetShaderConstantTable	PROTO :DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXGatherFragments:
;// -------------------
;// Assembles shader fragments into a buffer to be passed to a fragment linker.
;//   will generate shader fragments for all fragments in the file
;//
;// Parameters:
;//  pSrcFile
;//      Source file name
;//  hSrcModule
;//      Module handle. if NULL, current module will be used
;//  pSrcResource
;//      Resource name in module
;//  pSrcData
;//      Pointer to source code
;//  SrcDataLen
;//      Size of source code, in bytes
;//  pDefines
;//      Optional NULL-terminated array of preprocessor macro definitions.
;//  pInclude
;//      Optional interface pointer to use for handling #include directives.
;//      If this parameter is NULL, #includes will be honored when assembling
;//      from file, and will error when assembling from resource or memory.
;//  Flags
;//      See D3DXSHADER_xxx flags
;//  ppShader
;//      Returns a buffer containing the created shader fragments.  This buffer contains
;//      the assembled shader code, as well as any embedded debug info.
;//  ppErrorMsgs
;//      Returns a buffer containing a listing of errors and warnings that were
;//      encountered during assembly.  If you are running in a debugger,
;//      these are the same messages you will see in your debug output.
;//----------------------------------------------------------------------------

D3DXGatherFragmentsFromFileA	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXGatherFragmentsFromFileW	PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXGatherFragmentsFromFile	equ D3DXGatherFragmentsFromFileW
else
D3DXGatherFragmentsFromFile	equ D3DXGatherFragmentsFromFileA
endif

D3DXGatherFragmentsFromResourceA PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD
D3DXGatherFragmentsFromResourceW PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

ifdef UNICODE
D3DXGatherFragmentsFromResource equ D3DXGatherFragmentsFromResourceW
else
D3DXGatherFragmentsFromResource equ D3DXGatherFragmentsFromResourceA
endif

D3DXGatherFragments		PROTO :DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD,:DWORD

;//----------------------------------------------------------------------------
;// D3DXCreateFragmentLinker:
;// -------------------------
;// Creates a fragment linker with a given cache size.  The interface returned 
;// can be used to link together shader fragments.  (both HLSL & ASM fragements)
;//
;// Parameters:
;//  pDevice
;//      Pointer to the device on which to create the shaders
;//  ShaderCacheSize
;//      Size of the shader cache
;//  ppFragmentLinker
;//      pointer to a memory location to put the created interface pointer
;//
;//----------------------------------------------------------------------------

D3DXCreateFragmentLinker	PROTO :DWORD,:DWORD,:DWORD

;//////////////////////////////////////////////////////////////////////////////
;// Shader comment block layouts //////////////////////////////////////////////
;//////////////////////////////////////////////////////////////////////////////

;//----------------------------------------------------------------------------
;// D3DXSHADER_CONSTANTTABLE:
;// -------------------------
;// Shader constant information; included as an CTAB comment block inside
;// shaders.  All offsets are BYTE offsets from start of CONSTANTTABLE struct.
;// Entries in the table are sorted by Name in ascending order.
;//----------------------------------------------------------------------------

_D3DXSHADER_CONSTANTTABLE struct
	dx_Size		DWORD ? ;// sizeof(D3DXSHADER_CONSTANTTABLE)
	Creator		DWORD ? ;// LPCSTR offset
	Version		DWORD ? ;// shader version
	Constants	DWORD ? ;// number of constants
	ConstantInfo	DWORD ? ;// D3DXSHADER_CONSTANTINFO[Constants] offset
	Flags		DWORD ? ;// flags shader was compiled with
	Target		DWORD ? ;// LPCSTR offset 
_D3DXSHADER_CONSTANTTABLE ends

D3DXSHADER_CONSTANTTABLE	typedef _D3DXSHADER_CONSTANTTABLE
LPD3DXSHADER_CONSTANTTABLE	typedef PTR _D3DXSHADER_CONSTANTTABLE

_D3DXSHADER_CONSTANTINFO struct
	Name 		DWORD ? ;// LPCSTR offset
	RegisterSet	WORD  ? ;// D3DXREGISTER_SET
	RegisterIndex	WORD  ? ;// register number
	RegisterCount	WORD  ? ;// number of registers
	Reserved	WORD  ? ;// reserved
	TypeInfo	DWORD ? ;// D3DXSHADER_TYPEINFO offset
	DefaultValue	DWORD ? ;// offset of default value
_D3DXSHADER_CONSTANTINFO ends

D3DXSHADER_CONSTANTINFO		typedef _D3DXSHADER_CONSTANTINFO
LPD3DXSHADER_CONSTANTINFO	typedef PTR _D3DXSHADER_CONSTANTINFO

_D3DXSHADER_TYPEINFO struct
	dx_Class	WORD  ? ;// D3DXPARAMETER_CLASS
	dx_Type		WORD  ? ;// D3DXPARAMETER_TYPE
	Rows		WORD  ? ;// number of rows (matrices)
	Columns		WORD  ? ;// number of columns (vectors and matrices)
	Elements	WORD  ? ;// array dimension
	StructMembers	WORD  ? ;// number of struct members
	StructMemberInfo DWORD  ? ;// D3DXSHADER_STRUCTMEMBERINFO[Members] offset
_D3DXSHADER_TYPEINFO ends

D3DXSHADER_TYPEINFO	typedef _D3DXSHADER_TYPEINFO
LPD3DXSHADER_TYPEINFO	typedef PTR _D3DXSHADER_TYPEINFO

_D3DXSHADER_STRUCTMEMBERINFO struct
	Name		DWORD ? ;// LPCSTR offset
	TypeInfo	DWORD ? ;// D3DXSHADER_TYPEINFO offset
_D3DXSHADER_STRUCTMEMBERINFO ends

D3DXSHADER_STRUCTMEMBERINFO	typedef _D3DXSHADER_STRUCTMEMBERINFO
LPD3DXSHADER_STRUCTMEMBERINFO	typedef PTR _D3DXSHADER_STRUCTMEMBERINFO

endif ;//__D3DX9SHADER_H__
